_positive = set(
    [
        "abba",
        "Fähigkeit",
        "NO TRANSLATION",
        "absolut",
        "Absolution",
        "absorbiert",
        "reichlich",
        "akademisch",
        "Akademie",
        "akzeptabel",
        "Annahme",
        "zugänglich",
        "Akkolade",
        "Unterkunft",
        "Begleitung",
        "erreichen",
        "erreicht",
        "Leistung",
        "Übereinstimmung",
        "Rechenschaftspflicht",
        "verantwortlich",
        "akkreditiert",
        "NO TRANSLATION",
        "genau",
        "As",
        "leisten",
        "Leistung",
        "Wissen",
        "erwerben",
        "Erwerben",
        "Akrobat",
        "Aktion",
        "tatsächlich",
        "Schärfe",
        "Scharfsinn",
        "anpassen",
        "anpassungsfähig",
        "Adressen",
        "geschickt",
        "NO TRANSLATION",
        "Zusatz",
        "bewundernswert",
        "Admiral",
        "Bewunderung",
        "bewundern",
        "Bewunderer",
        "zulässig",
        "bezaubernd",
        "Anbetung",
        "verehren",
        "Voraus",
        "fortgeschritten",
        "Förderung",
        "Vorteil",
        "vorteilhaft",
        "Advent",
        "Abenteuer",
        "abenteuerlich",
        "ratsam",
        "beraten",
        "Berater",
        "Interessenvertretung",
        "ästhetisch",
        "Ästhetik",
        "freundlich",
        "Zuneigung",
        "angegliedert",
        "bestätigen",
        "Bejahung",
        "positiv",
        "bejahend",
        "Wohlstand",
        "wohlhabend",
        "sich leisten",
        "NO TRANSLATION",
        "agil",
        "Beweglichkeit",
        "zustimmen",
        "angenehm",
        "einverstanden",
        "zustimmen",
        "Zustimmung",
        "Landwirtschaft",
        "voraus",
        "Hilfe",
        "Unterstützung",
        "Alabaster",
        "Wachsamkeit",
        "NO TRANSLATION",
        "am Leben",
        "zerstreuen",
        "Treue",
        "allegro",
        "lindern",
        "Linderung",
        "verbündet",
        "zulässig",
        "locken",
        "verlockend",
        "Verbündete",
        "allmächtig",
        "Aloha",
        "erstaunlich",
        "Botschafter",
        "Ambition",
        "verbessern",
        "Amen",
        "zugänglich",
        "ändern",
        "ändert",
        "Annehmlichkeit",
        "liebenswürdig",
        "freundschaftlich",
        "Amnestie",
        "NO TRANSLATION",
        "amüsieren",
        "amüsiert",
        "Amüsement",
        "lustig",
        "Analytiker",
        "Anker",
        "Anchorage",
        "Engel",
        "Engel",
        "animieren",
        "animiert",
        "Antibiotika",
        "Gegenmittel",
        "antimykotisch",
        "Antiquität",
        "Antiseptikum",
        "Gelassenheit",
        "entschuldigend",
        "entschuldigen",
        "Entschuldigung",
        "Apostel",
        "Beifall",
        "Anerkennung",
        "Billigung",
        "die Genehmigung",
        "genehmigen",
        "genehmigend",
        "geeignet",
        "Eignung",
        "Archäologie",
        "glühend",
        "Eifer",
        "Adel",
        "aristokratisch",
        "Rüstung",
        "Aroma",
        "erregen",
        "Array",
        "Kunst",
        "artikulieren",
        "Artikulation",
        "Handwerker",
        "NO TRANSLATION",
        "künstlerisch",
        "Überlegenheit",
        "Aufstieg",
        "Aspiration",
        "streben",
        "aufstrebend",
        "Versammlung",
        "Zustimmung",
        "behauptend",
        "Vermögenswerte",
        "helfen",
        "Hilfe",
        "assoziieren",
        "Beschwichtigung",
        "Sicherheit",
        "versicherte",
        "NO TRANSLATION",
        "Erstaunen",
        "Astrologe",
        "Astronaut",
        "Astronom",
        "klug",
        "Athlet",
        "sportlich",
        "Atom",
        "büßen",
        "Sühne",
        "Befestigung",
        "erreichbar",
        "Erreichung",
        "Begleiter",
        "Beachtung",
        "aufmerksam",
        "bezeugen",
        "Rechtsanwalt",
        "Attraktion",
        "Attraktivität",
        "vermehren",
        "August",
        "Tante",
        "Aura",
        "verheißungsvoll",
        "authentisch",
        "Authentizität",
        "Autor",
        "maßgeblich",
        "Behörde",
        "Genehmigung",
        "autorisiert",
        "Benutzerbild",
        "vergeben",
        "Ja",
        "Ja",
        "Baby",
        "Abitur",
        "Rückgrat",
        "Balance",
        "ausgewogen",
        "Ballade",
        "Ballett",
        "Abstimmung",
        "Balsam",
        "Bankett",
        "Taufe",
        "Taufe",
        "Barde",
        "Schnäppchen",
        "Basketball",
        "Bastion",
        "Bad",
        "Strahl",
        "strahlend",
        "Verschönerung",
        "schön",
        "verschönern",
        "Schönheit",
        "Grundgestein",
        "Bier",
        "gebührend",
        "sich anfreunden",
        "glaubend",
        "Wohltäter",
        "vorteilhaft",
        "Vorteil",
        "Wohlwollen",
        "gutartig",
        "Liegeplatz",
        "verlobt",
        "Verbesserung",
        "Getränk",
        "biblisch",
        "zweisprachig",
        "Geburt",
        "Geburtstag",
        "untadelig",
        "segnen",
        "gesegnet",
        "Segen",
        "Segen",
        "Glückseligkeit",
        "glückselig",
        "unblutig",
        "blühen",
        "blühen",
        "Leibwächter",
        "Fett gedruckt",
        "Mut",
        "Nackenrolle",
        "Goldgrube",
        "NO TRANSLATION",
        "Bonus",
        "Bücher",
        "Buchgeschäft",
        "Segen",
        "freigebig",
        "Kopfgeld",
        "Strauß",
        "Gehirne",
        "Mut",
        "Frühstück",
        "Braut-",
        "Braut",
        "Bräutigam",
        "Brautjungfer",
        "aufhellen",
        "Helligkeit",
        "brillant",
        "Brokat",
        "Bruder",
        "Bruderschaft",
        "brüderlich",
        "Kumpel",
        "bauen",
        "Gebäude",
        "Bulldogge",
        "kugelsicher",
        "Boje",
        "Bus",
        "Diener",
        "buttrig",
        "drall",
        "summen",
        "Taxi",
        "Kabinett",
        "Cafe",
        "Taschenrechner",
        "Kalb",
        "Ruhe",
        "Kanarienvogel",
        "offen",
        "Kandidat",
        "kandiert",
        "Kapitalist",
        "Kapitän",
        "bestechen",
        "fesselnd",
        "Werdegang",
        "Vorsichtig",
        "vorsichtig",
        "streicheln",
        "Hausmeister",
        "Weihnachtslied",
        "Kaskade",
        "Kasse",
        "kategorisch",
        "verschenken",
        "kathartisch",
        "Dom",
        "vorsichtig",
        "vorsichtig",
        "gefeiert",
        "feiert",
        "Feier",
        "himmlisch",
        "Center",
        "Zenturio",
        "zerebral",
        "Zeremonie",
        "Sicherheit",
        "Vorsitzende",
        "Vorsitzende",
        "Champion",
        "Gesang",
        "Ladegerät",
        "wohltätig",
        "Nächstenliebe",
        "Charme",
        "charmant",
        "Keuschheit",
        "schnatternd",
        "Prüfliste",
        "jubeln",
        "heiter",
        "Fröhlichkeit",
        "Jubel",
        "NO TRANSLATION",
        "Chemiker",
        "hegen",
        "Kirsche",
        "Häuptling",
        "Kind",
        "Kindheit",
        "zwitschern",
        "Meißel",
        "Ritterlichkeit",
        "Schokolade",
        "Wahl",
        "Chor",
        "Chor-",
        "Chor",
        "gewählt",
        "Chowder",
        "Chronik",
        "Kichern",
        "Kirche",
        "Apfelwein",
        "Beschneidung",
        "Bürger",
        "bürgerlich",
        "Höflichkeit",
        "Zivilisation",
        "zivilisiert",
        "Hellseher",
        "klatschen",
        "klären",
        "klassisch",
        "klassisch",
        "Klassiker",
        "klassifizieren",
        "reinigen",
        "Reinigung",
        "Sauberkeit",
        "sauber",
        "reinigen",
        "Reinigung",
        "Spielraum",
        "Klarheit",
        "klerikal",
        "klug",
        "Klugheit",
        "Höhepunkt",
        "Nähe",
        "Schließung",
        "NO TRANSLATION",
        "Clown",
        "Koalition",
        "Küste",
        "koexistieren",
        "überzeugend",
        "kognitiv",
        "Kohärenz",
        "kohärent",
        "zusammenhängend",
        "gemeinsam",
        "Oberst",
        "kolossal",
        "Komfort",
        "Kommandant",
        "kommandierend",
        "gedenken",
        "Gedenkfeier",
        "Gedenk-",
        "empfehlen",
        "lobenswert",
        "Kommentator",
        "engagiert sein",
        "Kommodore",
        "Commonwealth",
        "kommunizieren",
        "gesprächig",
        "Gemeinschaft",
        "Gemeinschaft",
        "Kommutierung",
        "pendeln",
        "Begleiter",
        "Barmherzigkeit",
        "mitfühlend",
        "Kompatibilität",
        "kompatibel",
        "zwingend",
        "kompensieren",
        "Ausgleichs",
        "Kompetenz",
        "Kompetenz",
        "kompetent",
        "Selbstzufriedenheit",
        "ergänzen",
        "komplementär",
        "vollständig",
        "Vollständigkeit",
        "vervollständigen",
        "Fertigstellung",
        "Beachtung",
        "konform",
        "NO TRANSLATION",
        "zusammengesetzt",
        "Komponist",
        "Gelassenheit",
        "begreifen",
        "umfassend",
        "Genosse",
        "konzentrisch",
        "Schlichtung",
        "abschließend",
        "Eintracht",
        "Konkordanz",
        "Beileid",
        "dulden",
        "förderlich",
        "Leitfähigkeit",
        "verbündet",
        "Vertrauen",
        "zuversichtlich",
        "Bestätigt",
        "Konformität",
        "sympathisch",
        "Glückwunsch",
        "Gemeinde",
        "Kongruenz",
        "Kenner",
        "Gewissen",
        "gewissenhaft",
        "Bewusstsein",
        "Weihe",
        "Erhaltung",
        "sparen",
        "beträchtlich",
        "rücksichtsvoll",
        "Konsistenz",
        "Konsole",
        "Konsonant",
        "Konstanz",
        "Konstante",
        "konstitutionelle",
        "bauen",
        "vollendet",
        "Kontakt",
        "Betrachtung",
        "Inhalt",
        "fortsetzen",
        "Kontur",
        "beitragen",
        "Mitwirkende",
        "Bequemlichkeit",
        "praktisch",
        "Kloster",
        "Konvention",
        "vertraut",
        "Konversation",
        "Konvertieren",
        "überzeugen",
        "cool",
        "Kühle",
        "kooperieren",
        "zusammenarbeiten",
        "Zusammenarbeit",
        "Kooperative",
        "Ader",
        "Krönung",
        "Konzern",
        "körperlich",
        "korrigierend",
        "Korrespondenz",
        "bestätigen",
        "kosmopolitisch",
        "gemütlich",
        "Rat",
        "Rat",
        "Berater",
        "Anzahl",
        "Gräfin",
        "Mut",
        "mutig",
        "höflich",
        "Höflichkeit",
        "Balz",
        "Bucht",
        "Bund",
        "Wiege",
        "Kunst",
        "Handwerker",
        "Sahne",
        "erstellen",
        "kreativ",
        "Glaubwürdigkeit",
        "Anmeldeinformationen",
        "Glaubwürdigkeit",
        "glaubwürdig",
        "Kredit",
        "NO TRANSLATION",
        "gutgeschrieben",
        "Crescendo",
        "Kritik",
        "Krönung",
        "entscheidend",
        "Kristall",
        "kuscheln",
        "kulinarisch",
        "Höhepunkt",
        "pflegen",
        "kultiviert",
        "Anbau",
        "Kultur",
        "heilbar",
        "Neugierde",
        "Locke",
        "Kissen",
        "Kunde",
        "niedlich",
        "Schneider",
        "Dame",
        "tanzen",
        "gewagt",
        "Liebling",
        "schneidig",
        "Tochter",
        "Dämmerung",
        "Deal",
        "sehr geehrter",
        "Debatte",
        "Anstand",
        "anständig",
        "deklaratorische",
        "Widmung",
        "verteidigen",
        "verteidigt",
        "Verteidiger",
        "verteidigend",
        "Verteidigung",
        "Ehrerbietung",
        "definitiv",
        "Grad",
        "köstlich",
        "delegieren",
        "beraten",
        "köstlich",
        "Freude",
        "Erfreut",
        "herrlich",
        "Befreiung",
        "Lieferung",
        "Demokratie",
        "nachweisbar",
        "demonstrativ",
        "Tiefe",
        "beschreibend",
        "verdienen",
        "verdient",
        "Designer",
        "wünschenswert",
        "begehrend",
        "begierig",
        "Ziel",
        "erkennen",
        "Erkennung",
        "Entschlossenheit",
        "entschlossen",
        "entwickeln",
        "hingebungsvoll",
        "fromm",
        "Geschicklichkeit",
        "Diamant",
        "Tagebuch",
        "Wörterbuch",
        "didaktisch",
        "Diät",
        "würdevoll",
        "Würde",
        "Sorgfalt",
        "Abendessen",
        "Diplomatie",
        "diplomatisch",
        "Direktor",
        "Entdeckung",
        "NO TRANSLATION",
        "Diskretion",
        "diskretionär",
        "Diskussion",
        "Desinfektion",
        "entsorgt",
        "verbreiten",
        "Destillation",
        "Unterscheidung",
        "Liedchen",
        "abwechslungsreich",
        "Umleitung",
        "Gottheit",
        "Arzt",
        "Macher",
        "verbissen",
        "Delphin",
        "Don",
        "Spende",
        "zweifellos",
        "Taube",
        "flaumig",
        "Duett",
        "Herzog",
        "Haltbarkeit",
        "dauerhaft",
        "pflichtbewusst",
        "eifrig",
        "Eifer",
        "Graf",
        "verdienen",
        "Ernst",
        "ernsthaft",
        "Ernst",
        "Leichtigkeit",
        "Erleichterung",
        "NO TRANSLATION",
        "Essen",
        "Ekstase",
        "begeistert",
        "Erbauung",
        "erziehen",
        "gebildet",
        "lehrreich",
        "Wirksam",
        "Wirksamkeit",
        "Effizienz",
        "effizient",
        "Anstrengung",
        "Ejakulation",
        "Ausarbeitung",
        "begeistert",
        "ältere",
        "Älteste",
        "wählen",
        "elektrisch",
        "Elektrizität",
        "Eleganz",
        "elegant",
        "Elevation",
        "berechtigt",
        "Elite",
        "Beredsamkeit",
        "beredt",
        "aufklären",
        "Emanzipation",
        "Umarmung",
        "Emeritus",
        "Eminenz",
        "eminent",
        "eminent",
        "NO TRANSLATION",
        "Empathie",
        "ermächtigen",
        "emulieren, nacheifern",
        "aktivieren",
        "Ermöglichung",
        "verzaubern",
        "verzaubert",
        "zauberhaft",
        "NO TRANSLATION",
        "ermutigen",
        "Förderung",
        "Enzyklopädie",
        "bemühen",
        "schenken",
        "ausgestattet",
        "Ausstattung",
        "Ausdauer",
        "ertragen",
        "energisch",
        "beschäftigt, verlobt",
        "ansprechend",
        "verbessern",
        "genießen",
        "genießen",
        "erleuchten",
        "Aufklärung",
        "beleben",
        "bereichern",
        "Ensemble",
        "Fähnrich",
        "unternehmungslustig",
        "unterhalten",
        "unterhalten",
        "unterhaltsam",
        "Unterhaltung",
        "Begeisterung",
        "Enthusiast",
        "NO TRANSLATION",
        "Ephemeriden",
        "Epos",
        "Inbegriff",
        "Gleichberechtigung",
        "gleichermaßen",
        "Gleichgewicht",
        "Billigkeit",
        "Auftrag",
        "gelehrt",
        "Esprit",
        "wesentlich",
        "etabliert",
        "Wertschätzung",
        "ästhetisch",
        "ethisch",
        "Ethik",
        "immergrün",
        "ewig",
        "offensichtlich",
        "Evolution",
        "erhöhen",
        "Erhöhung",
        "erhaben",
        "überschreiten",
        "übertreffen",
        "Exzellenz",
        "Ausgezeichnet",
        "Austausch-",
        "erregbar",
        "Erregung",
        "anregen",
        "aufgeregt",
        "Aufregung",
        "aufregend",
        "exemplarisch",
        "Befreiung",
        "Erheiterung",
        "ermahnen",
        "Ermahnung",
        "Existenz",
        "exotisch",
        "erwarten von",
        "Erwartung",
        "zweckmäßig",
        "Expedition",
        "erfahren",
        "Experte",
        "Sachverstand",
        "erklären",
        "exquisit",
        "exquisit",
        "erweitern",
        "umfangreich",
        "extra",
        "außergewöhnlich",
        "befreien",
        "Überschwang",
        "erleichtern",
        "Fakten",
        "Fakultät",
        "NO TRANSLATION",
        "Messe",
        "ziemlich",
        "Glauben",
        "treu",
        "Ruhm",
        "familiär",
        "Vertrautheit",
        "berühmt",
        "berühmt",
        "schick",
        "Fanfare",
        "faszinierend",
        "Faszination",
        "modisch",
        "fehlerlos",
        "günstig",
        "Favorit",
        "Bevorzugung",
        "furchtlos",
        "Leistung",
        "Feature",
        "Glückseligkeit",
        "Gefährte",
        "Gemeinschaft",
        "weiblich",
        "fruchtbar",
        "Inbrunst",
        "Festival",
        "festlich",
        "NO TRANSLATION",
        "Treue",
        "Fiesta",
        "endlich",
        "Putz",
        "Finesse",
        "Feuerball",
        "feuerfest",
        "Festigkeit",
        "NO TRANSLATION",
        "passend zu",
        "Befestigung",
        "schmeichelhaft",
        "Flotte",
        "Flexibilität",
        "Blumen-",
        "fließen",
        "blumig",
        "spülen",
        "fliegend",
        "Fokus",
        "Vorliebe",
        "Lebensmittel",
        "Fußball",
        "Nachsicht",
        "Vordergrund",
        "Vorfahren",
        "vorstehend",
        "Vorarbeiter",
        "Vorläufer",
        "voraussehen",
        "vorgesehen",
        "Voraussicht",
        "Schmiede",
        "verzeihen",
        "vergeben",
        "versöhnlich",
        "prägend",
        "Formel",
        "NO TRANSLATION",
        "in Kürze",
        "stärken",
        "Kraft",
        "Festung",
        "glücklich",
        "Vermögen",
        "nach vorne",
        "gefunden",
        "Stiftung",
        "duftend",
        "frank",
        "Offenheit",
        "brüderlich",
        "Freiheit",
        "frei",
        "Freund",
        "Freundlichkeit",
        "freundlich",
        "Freundschaft",
        "munter",
        "Scherz",
        "sparsam",
        "fruchtbar",
        "erfüllen",
        "Erfüllung",
        "voll",
        "völlig",
        "Spaß",
        "grundlegend",
        "Sicherung",
        "Verschmelzung",
        "gewinnen",
        "Gewinnung",
        "galant",
        "Galanterie",
        "in Hülle und Fülle",
        "Garten",
        "Granat",
        "Garnison",
        "Gazette",
        "Ausrüstung",
        "Juwel",
        "Allgemeines",
        "Großzügigkeit",
        "großzügig",
        "genial",
        "Genius",
        "vornehm",
        "Gentleman",
        "Sanftmut",
        "Gentry",
        "Original-",
        "Geranie",
        "Geschenk",
        "begabtes",
        "riesig",
        "kichern",
        "Träger",
        "geben",
        "froh",
        "Freude",
        "Freude",
        "gleiten",
        "Glimmer",
        "glänzend",
        "Verherrlichung",
        "verherrlichen",
        "Ruhm",
        "Glanz",
        "glühen",
        "glühend",
        "Gott",
        "göttlich",
        "Geschenk des Himmels",
        "Gold",
        "gut",
        "gut",
        "Güte",
        "Waren",
        "Goodwill",
        "Herrlich",
        "Evangelium",
        "regieren",
        "Anmut",
        "anmutig",
        "gnädig",
        "gnädig",
        "Abschluss",
        "Enkelkinder",
        "Größe",
        "Oma",
        "gewähren",
        "gewährt",
        "dankbar",
        "befriedigen",
        "Dankbarkeit",
        "größer",
        "Größe",
        "Grün",
        "Gruß",
        "gesellig",
        "Grinsen",
        "Mahlgut",
        "Streugut",
        "Grundlage",
        "wachsen",
        "Wachstum",
        "Garantie",
        "bewachen",
        "Wächter",
        "Vormundschaft",
        "Gouverneursamt",
        "Beratung",
        "führen",
        "Reiseführer",
        "Guru",
        "Eingeweide",
        "Turner",
        "Lebensraum",
        "gesund",
        "praktisch",
        "glücklich",
        "Glück",
        "glücklich",
        "winterhart",
        "harmonisch",
        "Harmonie",
        "Ernte",
        "Oase",
        "Fortschritt",
        "heilen",
        "Heilung",
        "gesund",
        "gesund",
        "tief empfunden",
        "Feuerstelle",
        "herzlich",
        "paradiesisch",
        "Himmel",
        "Gewicht",
        "Helm",
        "Helfer",
        "hilfreich",
        "Kräuter-",
        "Held",
        "heroisch",
        "Heldentaten",
        "Heldin",
        "Heldentum",
        "Blütezeit",
        "unglaublich witzig",
        "Heiterkeit",
        "mieten",
        "Hobby",
        "Urlaub",
        "Heiligkeit",
        "heilig",
        "Huldigung",
        "Homologie",
        "ehrlich",
        "Ehrlichkeit",
        "Honig",
        "Flitterwochen",
        "Ehre",
        "ehrenhaft",
        "Hoffnung",
        "hoffnungsvoll",
        "Horizont",
        "Gastfreundschaft",
        "Haushalt",
        "Hauswirtschaft",
        "Umarmung",
        "menschlich",
        "humanitäre",
        "Menschheit",
        "gedemütigt",
        "demütig",
        "Demut",
        "Humorist",
        "humorvoll",
        "Hurra",
        "Haltung",
        "Stille",
        "Hütte",
        "hygienisch",
        "Hymne",
        "Idealismus",
        "Idol",
        "NO TRANSLATION",
        "Erleuchtung",
        "veranschaulichen",
        "illustre",
        "fantasievoll",
        "makellos",
        "immens",
        "tauchen",
        "unsterblich",
        "vermitteln",
        "unparteiisch",
        "Unparteilichkeit",
        "einwandfrei",
        "undurchlässig",
        "Bedeutung",
        "wichtig",
        "beeindrucken",
        "Eindruck",
        "verbessern",
        "verbessert",
        "Verbesserung",
        "Verbesserung",
        "improvisieren",
        "unveräußerlich",
        "Einweihung",
        "einschneidend",
        "einschließen",
        "inbegriffen",
        "einschließlich",
        "inklusive",
        "erhöhen, ansteigen",
        "unauslöschlich",
        "Entschädigung",
        "Unabhängigkeit",
        "unzerstörbar",
        "Individualität",
        "unbezähmbar",
        "unsagbar",
        "günstig",
        "unfehlbar",
        "Säugling",
        "unendlich",
        "Unendlichkeit",
        "einflussreich",
        "Information",
        "genial",
        "Erbe",
        "unnachahmlich",
        "Unschuld",
        "unschuldig",
        "unschuldig",
        "harmlos",
        "innovieren",
        "Innovation",
        "Nachforschender",
        "Anfrage",
        "neugierig",
        "untrennbar",
        "Insignien",
        "Inspektor",
        "Inspiration",
        "inspirieren",
        "inspiriert",
        "instinktiv",
        "anweisen",
        "Anweisung",
        "Lehrer",
        "instrumental",
        "versichern",
        "intakt",
        "Integrität",
        "Intellekt",
        "geistig",
        "Intelligenz",
        "intelligent",
        "beabsichtigt",
        "Verkehr",
        "Interesse",
        "interessiert",
        "interessant",
        "Innere",
        "Zwischenentscheidungen",
        "Zwischenspiel",
        "intim",
        "Intonation",
        "unerschrocken",
        "Intuition",
        "intuitiv",
        "unveränderlich",
        "originell",
        "Erfinder",
        "untersuchen",
        "beleben",
        "Einladung",
        "einladen",
        "einladend",
        "Eisen",
        "nicht reduzierbar",
        "unwiderlegbar",
        "Jackpot",
        "Marmelade",
        "NO TRANSLATION",
        "Job",
        "Beitreten",
        "beigetreten",
        "Joker",
        "scherzen",
        "Journalist",
        "Reise",
        "gemütlich",
        "Freude",
        "froh",
        "fröhlich",
        "jubelnd",
        "Jubiläum",
        "gerichtlich",
        "vernünftig",
        "springen",
        "Gerechtigkeit",
        "gerechtfertigt",
        "Rechtfertigung",
        "Andenken",
        "ken",
        "Grundton",
        "Keystone",
        "nett",
        "Freundlichkeit",
        "Verwandtschaft",
        "König",
        "Kuss",
        "Kätzchen",
        "Talent",
        "Ritter",
        "zu wissen",
        "Wissen",
        "Kudos",
        "Arbeit",
        "Lamm",
        "Land",
        "gelandet",
        "Laser-",
        "lobenswert",
        "Lachen",
        "Lachen",
        "Lachen",
        "starten",
        "Preisträger",
        "Lorbeer",
        "Lorbeer",
        "verschwenderisch",
        "rechtmäßig",
        "führen",
        "Führer",
        "Liga",
        "lernen",
        "Lernen",
        "Dozent",
        "Spielraum",
        "legal",
        "legalisiert",
        "legendär",
        "Lesbarkeit",
        "lesbar",
        "Freizeit",
        "gemächlich",
        "Lemma",
        "nachsichtig",
        "Lektion",
        "beschriftet",
        "Niveau",
        "Hebelwirkung",
        "befreien",
        "Befreiung",
        "Freiheit",
        "Bibliothek",
        "Lebensnerv",
        "Leuchtturm",
        "Geschmack",
        "Linguist",
        "Löwe",
        "geschmeidig",
        "logisch",
        "Langlebigkeit",
        "Lordschaft",
        "liebenswert",
        "Liebe",
        "schön",
        "NO TRANSLATION",
        "Liebhaber",
        "liebend",
        "treu",
        "Loyalität",
        "Glück",
        "Glücklich",
        "üppig",
        "Lüster",
        "glänzend",
        "üppig",
        "luxuriös",
        "Luxus",
        "Leier",
        "lyrisch",
        "magisch",
        "Magnet",
        "Magnetismus",
        "Magnetit",
        "Pracht",
        "herrlich",
        "Mädchen",
        "Main",
        "Hauptstütze",
        "majestätisch",
        "Majestät",
        "Haupt",
        "Mehrheit",
        "verwalten",
        "Management",
        "Mandarin",
        "Männlichkeit",
        "manifestiert",
        "männlich",
        "Manna",
        "manieriert",
        "Sitten und Bräuche",
        "Hersteller",
        "März",
        "markiert",
        "marktfähig",
        "Marquis",
        "Ehe",
        "Mark",
        "heiraten",
        "Marschall",
        "Wunder",
        "fabelhaft",
        "wunderbar",
        "männlich",
        "Massage",
        "Meister",
        "Meisterstück",
        "Meisterschaft",
        "Kamerad",
        "Ehe",
        "Matrone",
        "maximal",
        "Bürgermeister",
        "Wiese",
        "gemessen",
        "Medaille",
        "vermitteln",
        "Vermittlung",
        "Vermittler",
        "medizinisch",
        "NO TRANSLATION",
        "Mittelmeer",
        "Medley",
        "Erinnerung",
        "unvergesslich",
        "ausbessern",
        "Menses",
        "Mentor",
        "barmherzig",
        "barmherzig",
        "verschmelzen",
        "verdienen",
        "verdienstvoll",
        "Heiterkeit",
        "fröhlich",
        "Metropolitan-",
        "Eifer",
        "Mikroskopie",
        "Geburtshilfe",
        "mächtig",
        "Mime",
        "achtsam",
        "Achtsamkeit",
        "Ministerium",
        "Wunder",
        "Wunder-",
        "Heiterkeit",
        "Missionar",
        "Modell-",
        "mäßig",
        "Moderator",
        "bescheiden",
        "Bescheidenheit",
        "Schwung",
        "Geld",
        "Geld",
        "Mönch",
        "Monument",
        "Moral-",
        "Moral",
        "Moral",
        "Granatwerfer",
        "Mutterschaft",
        "Motiv",
        "beweglich",
        "Beweger",
        "muskulös",
        "Musik-",
        "Musical",
        "veränderlich",
        "gegenseitige",
        "Nickerchen",
        "Naturforscher",
        "schiffbar",
        "ordentlich",
        "Nektar",
        "Nadel",
        "verhandeln",
        "Unterhändler",
        "Nachbar",
        "Nerv",
        "schmiegen",
        "Adel",
        "edel",
        "Edelmann",
        "Nominierung",
        "Normalität",
        "bemerkenswert",
        "Honoratioren",
        "NO TRANSLATION",
        "Begriff",
        "Nahrung",
        "Zahlen",
        "Krankenschwester",
        "Kindergarten",
        "nähren",
        "nahrhaft",
        "Eiche",
        "Oase",
        "Eid",
        "Gehorsam",
        "Zielsetzung",
        "verbindlich",
        "aufmerksam",
        "erhältlich",
        "offensichtlich",
        "Bewohner",
        "Besetzung",
        "besetzen",
        "Angebot",
        "Offizier",
        "Offset",
        "Ableger",
        "allwissend",
        "Offenheit",
        "Oper",
        "opportun",
        "Gelegenheit",
        "Optimismus",
        "Optimist",
        "Möglichkeit",
        "wahlweise",
        "Orakel",
        "Rede",
        "Orchester",
        "ordiniert",
        "ordentlich",
        "Ordination",
        "organisch",
        "Organisation",
        "organisieren",
        "organisiert",
        "Orgasmus",
        "Originalität",
        "verziert",
        "aufwendig",
        "Ergebnis",
        "übertrumpfen",
        "nach außen",
        "überglücklich",
        "überwältigend",
        "Eigentum",
        "Pazifik",
        "Pad",
        "Polsterung",
        "Paddel",
        "schmackhaft",
        "palliativ",
        "Allheilmittel",
        "Elan",
        "NO TRANSLATION",
        "Paprika",
        "paragon",
        "überragend",
        "Pardon",
        "Abstammung",
        "parietal",
        "teilhaben",
        "Beteiligung",
        "Partner",
        "Partnerschaft",
        "Leidenschaft",
        "leidenschaftlich",
        "Zeitvertreib",
        "Pastor",
        "Gebäck",
        "Weide",
        "Patent",
        "die Geduld",
        "geduldig",
        "Patriarchalisch",
        "Patron",
        "Schirmherrschaft",
        "Zahlen",
        "Frieden",
        "friedlich",
        "friedlich",
        "Pfau",
        "picken",
        "Besonderheit",
        "Stammbaum",
        "unvergleichlich",
        "Vorliebe",
        "wahrnehmen",
        "wahrnehmbar",
        "Staude",
        "perfekt",
        "Perfektion",
        "Künstler",
        "Vorteil",
        "Genehmigung",
        "Ewigkeit",
        "Beharrlichkeit",
        "persistent",
        "sympathisch",
        "einschlägig",
        "Pharma",
        "Philanthrop",
        "Philanthropie",
        "Philosoph",
        "Phönix",
        "phonetisch",
        "Arzt",
        "Physik",
        "Physiologie",
        "Körperbau",
        "wähle",
        "Picknick",
        "malerisch",
        "Frömmigkeit",
        "Pille",
        "Kissen",
        "Pilot",
        "Höhepunkt",
        "Pionier",
        "fromm",
        "Mark",
        "schwenken",
        "ruhig",
        "Planung",
        "spielerisch",
        "Spielplatz",
        "Spielhaus",
        "angenehm",
        "zufrieden",
        "angenehm",
        "Versprechen",
        "Plenum",
        "reichlich",
        "Plexus",
        "Pflaume",
        "Lot",
        "Plüsch-",
        "Lagen",
        "spitz",
        "Polizei",
        "Polizist",
        "Polieren",
        "poliert",
        "höflich",
        "Höflichkeit",
        "NO TRANSLATION",
        "Schwimmbad",
        "Papst",
        "Popularität",
        "popularisiert",
        "Population",
        "tragbar",
        "besitzen",
        "trinkbar",
        "Potenz",
        "mächtig",
        "kraftvoll",
        "trainieren",
        "geübt",
        "trainieren",
        "loben",
        "gelobt",
        "lobenswert",
        "beten",
        "Vorsicht",
        "vorausgehen",
        "Vorrang",
        "kostbar",
        "präzise",
        "Präzision",
        "Vorliebe",
        "vorherrschend",
        "herausragend",
        "bevorzugen",
        "Premier",
        "Lokal",
        "bereiten",
        "bereit",
        "vorausschauend",
        "Gegenwart",
        "Geschenk",
        "vorzeigbar",
        "Konservierungsmittel",
        "erhalten",
        "Präsident",
        "Prestige",
        "Presto",
        "ziemlich",
        "herrschen",
        "Verhütung",
        "unbezahlbar",
        "Stolz",
        "Priester",
        "Priestertum",
        "priesterlich",
        "Primat",
        "primär",
        "prim",
        "Grundierung",
        "Prinz",
        "fürstlich",
        "Prinzessin",
        "Schulleiter",
        "unberührt",
        "privilegiert",
        "Redlichkeit",
        "Verfahren",
        "Prozession",
        "Proktor",
        "besorgen",
        "erstaunlich",
        "Wunder",
        "Hersteller",
        "produzierend",
        "Produktion",
        "produktiv",
        "Produktivität",
        "Beruf",
        "Professionel",
        "Professor",
        "Kompetenz",
        "kompetent",
        "reichlich",
        "Fortschritt",
        "Progression",
        "progressiv",
        "fruchtbar",
        "Bedeutung",
        "prominent",
        "versprechen",
        "vielversprechend",
        "Beförderung",
        "Stütze",
        "richtig",
        "Prophet",
        "prophylaktisch",
        "Vorschlag",
        "Aussicht",
        "gedeihen",
        "der Wohlstand",
        "wohlhabend",
        "schützen",
        "Schützen",
        "Schutz",
        "Schutz",
        "stolz",
        "beweisen",
        "sprichwörtlich",
        "zu Verfügung stellen",
        "Bereitstellung",
        "Klugheit",
        "umsichtig",
        "Psalm",
        "Öffentlichkeit",
        "ziehen",
        "Kanzel",
        "pünktlich",
        "Pünktlichkeit",
        "Hündchen",
        "rein",
        "Reinigung",
        "reinigen",
        "Purist",
        "Reinheit",
        "Schnurren",
        "urig",
        "qualifiziert",
        "qualifizierend",
        "Suche",
        "Frage",
        "Schnelligkeit",
        "ruhend",
        "ruhig",
        "Chinin",
        "Glanz",
        "strahlend",
        "strahlen",
        "Radio",
        "verzückt",
        "Entrückung",
        "rational",
        "Leser",
        "leicht",
        "Bereitschaft",
        "lesen",
        "bekräftigen",
        "echt",
        "Grund",
        "Beruhigung",
        "beruhigen",
        "Abzug",
        "Neufassung",
        "empfangen",
        "Empfang",
        "NO TRANSLATION",
        "erwidern",
        "Rückgewinnung",
        "zurücklehnen",
        "erkennbar",
        "empfehlen",
        "Versöhnung",
        "erneute Prüfung",
        "rekonstruieren",
        "Wiederaufbau",
        "Recorder",
        "wiedererlangen",
        "Wiederherstellung",
        "Erholung",
        "Freizeit",
        "beheben",
        "Erlösung",
        "Wiedergutmachung",
        "verfeinern",
        "Raffinesse",
        "Reform",
        "Reformation",
        "Reformer",
        "erfrischend",
        "renovieren",
        "Regal",
        "Regent",
        "Regelmäßigkeit",
        "regulieren",
        "rehabilitieren",
        "Rehabilitation",
        "erstatten",
        "Rückerstattung",
        "Verstärkung",
        "wieder herstellen",
        "jubeln",
        "Jubel",
        "verjüngen",
        "verjüngt",
        "Entspannung",
        "relevant",
        "Zuverlässigkeit",
        "zuverlässig",
        "Vertrauen",
        "Linderung",
        "entlastend",
        "Neuauflage",
        "bemerkenswert",
        "NO TRANSLATION",
        "Abhilfe",
        "Remission",
        "umgestalten",
        "Renaissance",
        "machen",
        "Erneuerung",
        "renovieren",
        "Renovierung",
        "Bekanntheit",
        "berühmt",
        "reorganisieren",
        "Wiedergutmachung",
        "zurückzahlen",
        "bereuen",
        "auffüllen",
        "voll",
        "Reporter",
        "Ruhe",
        "repräsentiert",
        "reproduktiv",
        "seriös",
        "Rettung",
        "Reservieren",
        "Bewohner",
        "elastisch",
        "resistiv",
        "entschlossen",
        "Ressourcen",
        "Respekt",
        "Seriosität",
        "respektabel",
        "respektvoll",
        "Respekt",
        "respektiert",
        "Aufschub",
        "prächtig",
        "verantwortlich",
        "ansprechbar",
        "sich ausruhen",
        "erholsam",
        "Restitution",
        "restaurativ",
        "Wiederherstellung",
        "Zurückhaltung",
        "Wiederaufnahme",
        "Zurückhaltung",
        "Wiedervereinigung",
        "revel",
        "genießt",
        "verehren",
        "Ehrfurcht",
        "ehrwürdig",
        "Träumereien",
        "revidieren",
        "Wiederbelebung",
        "Revolutionär",
        "Belohnung",
        "Rhythmus",
        "rhythmisch",
        "Band",
        "Reichtum",
        "Fahrer",
        "gerecht",
        "rechtmäßig",
        "richtig",
        "reif",
        "reifen",
        "steigend",
        "Nieten",
        "Roadster",
        "robust",
        "Rock",
        "Stange",
        "ausgelassen",
        "Romantik",
        "romantisch",
        "Romantik",
        "tummeln",
        "verwurzelt",
        "rosig",
        "Rota",
        "Routine",
        "Lizenzgebühren",
        "Rubrik",
        "Ruth",
        "sicher",
        "sichern",
        "Salbei",
        "Heilige",
        "heilig",
        "Gehalt",
        "hervorstechend",
        "heilsam",
        "Gruß",
        "Heil",
        "Salbe",
        "Samurai",
        "Heiligung",
        "heiligen",
        "Heiligtum",
        "lebhaft",
        "Sanitär",
        "Satin-",
        "zufriedenstellend",
        "zufrieden",
        "sparen",
        "Ersparnisse",
        "genießen",
        "Bohnenkraut",
        "kapieren",
        "Gelehrte",
        "Stipendium",
        "wissenschaftlich",
        "Wissenschaftler",
        "NO TRANSLATION",
        "Ergebnis",
        "Schreiber",
        "Skript",
        "lecker",
        "Skulptur",
        "Meer",
        "Dichtung",
        "gewürzt",
        "Sekretariat",
        "Dienstalter",
        "sensationell",
        "Sinn",
        "Sensibilität",
        "vernünftig",
        "Sinnlichkeit",
        "sinnlich",
        "sentimental",
        "Sentimentalität",
        "Wächter",
        "Gelassenheit",
        "Predigt",
        "Serum",
        "Begründer",
        "Sex",
        "gestalten",
        "wohlgeformt",
        "Aktie",
        "Schutz",
        "Schäfer",
        "scheinen",
        "leuchtenden",
        "Einkaufen",
        "Schulter",
        "klug",
        "Seide",
        "vereinfachen",
        "aufrichtig",
        "Aufrichtigkeit",
        "singen",
        "einzeln",
        "Herr",
        "Schwesternschaft",
        "qualifiziert",
        "geschickt",
        "Himmel",
        "Schiefer",
        "glatt",
        "schlank",
        "schlank",
        "Lächeln",
        "lächelnd",
        "geschlagen",
        "Glätte",
        "kichern",
        "Nüchternheit",
        "gesellig",
        "Trost",
        "Soldat",
        "solide",
        "Solidität",
        "Lösung",
        "Zahlungsfähigkeit",
        "Sonar",
        "Sonate",
        "Sonett",
        "klangvoll",
        "beruhigen",
        "beruhigend",
        "NO TRANSLATION",
        "Solidität",
        "Suppe",
        "Spa",
        "geräumig",
        "Spaniel",
        "funkeln",
        "Besondere",
        "NO TRANSLATION",
        "Rede",
        "schnell",
        "Rechtschreibung",
        "würzen",
        "Geist",
        "Spirituosen",
        "herrlich",
        "Pracht",
        "Sponsor",
        "makellos",
        "Ehepartner",
        "Fichte",
        "stabil",
        "staccato",
        "Edelstahl",
        "Hengst",
        "unerschütterlich",
        "Ausdauer",
        "Stehen",
        "Star",
        "Sternenlicht",
        "sternenklar",
        "herrschaftlich",
        "Erklärung",
        "Statue",
        "Status",
        "stillen",
        "standhaft",
        "stellar",
        "Steward",
        "Stille",
        "Geschäft",
        "einfach",
        "strategisch",
        "Stratege",
        "Stärke",
        "stärken",
        "Stärkung",
        "markant",
        "auffallend",
        "stark",
        "Struktur",
        "Zucht",
        "Studie",
        "robust",
        "Sublimation",
        "Substanz",
        "substantiv",
        "gelingen",
        "erfolgreich",
        "Erfolg",
        "erfolgreich",
        "prägnant",
        "Suffizienz",
        "Zucker",
        "geeignet",
        "schwül",
        "Sonne",
        "sonnig",
        "Sonnenuntergang",
        "Sonnenschein",
        "hervorragend",
        "übermenschlich",
        "überlegen",
        "Überlegenheit",
        "Übermensch",
        "Superstar",
        "Flehen",
        "Lieferungen",
        "liefern",
        "unterstützt",
        "Fan",
        "unterstützend",
        "höchste",
        "äußerst",
        "Sicherheit",
        "Vermutung",
        "übertreffend",
        "Überraschung",
        "Vermessung",
        "überleben",
        "schwören",
        "Süss",
        "Schatz",
        "Schätzchen",
        "Süße",
        "Süßigkeiten",
        "schnell",
        "schwimmen",
        "symbolisch",
        "symmetrisch",
        "Symmetrie",
        "sympathisch",
        "Sympathie",
        "Symphonie",
        "synchronisieren",
        "synergistisch",
        "Synode",
        "Takt",
        "Geschichte",
        "Talent",
        "Talisman",
        "sich unterhalten",
        "Braun gebrannt",
        "Aufgabe",
        "geschmackvoll",
        "lecker",
        "lehren",
        "Lehrer",
        "Technologie",
        "Mäßigkeit",
        "temperiert",
        "haltbar",
        "zäh",
        "Beharrlichkeit",
        "Mietvertrag",
        "Mieter",
        "zärtlich",
        "Zärtlichkeit",
        "dankbar",
        "das Erntedankfest",
        "theoretisch",
        "therapeutisch",
        "Therapeutika",
        "NO TRANSLATION",
        "Vollblut-",
        "nachdenklich",
        "Nachdenklichkeit",
        "Sparsamkeit",
        "Nervenkitzel",
        "spannend",
        "blühend",
        "Thron",
        "kitzeln",
        "Fliesen",
        "rechtzeitig",
        "Lametta",
        "Titel",
        "Toast",
        "tolerant",
        "Duldung",
        "oben",
        "Zähigkeit",
        "Turm",
        "hochragend",
        "traditionell",
        "still",
        "Ruhe",
        "Transzendenz",
        "transzendental",
        "Reisen",
        "Schatz",
        "Baum",
        "enorm",
        "Trend",
        "modisch",
        "Nebenfluss",
        "Tribut",
        "trig",
        "Triumph",
        "triumphierend",
        "Trophäe",
        "Waffenstillstand",
        "WAHR",
        "vertrauenswürdig",
        "Wahrheit",
        "Wahrhaftigkeit",
        "Vormundschaft",
        "Tutor",
        "Zwilling",
        "funkeln",
        "letzten Endes",
        "Schiedsrichter",
        "Einstimmigkeit",
        "einstimmig",
        "bescheiden",
        "unvoreingenommen",
        "unzerbrechlich",
        "ungebrochen",
        "ungezwungen",
        "unterstreichen",
        "Verstehen",
        "unterschreiben",
        "ungeteilt",
        "unsterblich",
        "eindeutig",
        "entfalten",
        "Vereinigung",
        "gleichmäßig",
        "nicht infiziert",
        "einzigartig",
        "Einklang",
        "einheitlich",
        "vereinigt",
        "Einheit",
        "Universität",
        "unbegrenzt",
        "unprätentiös",
        "unbestreitbar",
        "zweifellos",
        "unbestritten",
        "unversehrt",
        "selbstlos",
        "unübertroffen",
        "unerschütterlich",
        "erheben",
        "aufrecht",
        "Nützlichkeit",
        "Platzanweiser",
        "gewöhnlich",
        "Nützlichkeit",
        "utopisch",
        "Ferien",
        "Impfstoff",
        "tapfer",
        "NO TRANSLATION",
        "wertvoll",
        "Vorhut",
        "besiegen",
        "Samt",
        "samtig",
        "ehrwürdig",
        "Verehrung",
        "Richtigkeit",
        "grün",
        "Überprüfung",
        "verifiziert",
        "wahrlich",
        "veritable",
        "Frühling",
        "Verve",
        "Veteran",
        "Pfarrer",
        "Sieger",
        "siegreich",
        "Sieg",
        "Wachsamkeit",
        "wachsam",
        "Kraft",
        "kräftig",
        "Dorfbewohner",
        "bestätigt",
        "Rechtfertigung",
        "Jungfrau",
        "Jungfräulichkeit",
        "Tugend",
        "tugendhaft",
        "Vision",
        "visionär",
        "Besuch",
        "Besucher",
        "wichtig",
        "Vitalität",
        "lebhaft",
        "lebendig",
        "Wortschatz",
        "Freiwillige",
        "üppig",
        "verbürgen",
        "Gelübde",
        "Lohn",
        "Garantie",
        "Krieger",
        "Wachhund",
        "wachsam",
        "Wächter",
        "wasserdicht",
        "Reichtum",
        "wetterfest",
        "begrüßt",
        "Weiß",
        "Weiße",
        "gesund",
        "Wicket",
        "weit verbreitet",
        "bereitwillig",
        "Bereitschaft",
        "Glücksfall",
        "Gewinner",
        "gewinnen",
        "Gewinn",
        "kabellos",
        "WIS",
        "Weisheit",
        "weise",
        "Witz",
        "standhalten",
        "Verstand",
        "witzig",
        "Magier",
        "Gebärmutter",
        "wunderbar",
        "wunderbar",
        "wundersam",
        "Wort",
        "Arbeiten",
        "Anbetung",
        "wert",
        "würdig",
        "wot",
        "Schriftsteller",
        "jung",
        "jünger",
        "Jugend",
        "Eifer",
        "eifrig",
        "Zitrusschale",
    ]
)

_negative = set(
    [
        "verlassen",
        "verlassen",
        "Aufgabe",
        "Entführung",
        "anomal",
        "Abweichung",
        "verabscheuen",
        "abscheulich",
        "abwesend",
        "abnormal",
        "abschaffen",
        "Abschaffung",
        "abscheulich",
        "Gräuel",
        "abbrechen",
        "Abtreibung",
        "abtreibend",
        "Abrieb",
        "aufheben",
        "Abszess",
        "Abwesenheit",
        "abwesend",
        "abwesend",
        "Absentismus",
        "absurd",
        "Absurdität",
        "Missbrauch",
        "miserabel",
        "Abgrund",
        "Unfall",
        "versehentlich",
        "verflucht",
        "Anklage",
        "Akkusativ",
        "Angeklagte",
        "Ankläger",
        "beschuldigt",
        "schmerzen",
        "Schmerz",
        "Acid",
        "umsetzbar",
        "Addierer",
        "Sucht",
        "Fett",
        "entscheiden",
        "Ermahnung",
        "treibend",
        "verfälscht",
        "Ehebruch",
        "Gegner",
        "nachteilig",
        "Unglück",
        "bedrängen",
        "gequält",
        "Gebrechen",
        "Beleidigung",
        "Angst",
        "Nachwirkungen",
        "Nachgeschmack",
        "verschärft",
        "verschlimmernd",
        "Verschlimmerung",
        "Aggression",
        "aggressiv",
        "Aggressor",
        "entsetzt",
        "aufgeregt",
        "Agitation",
        "quälend",
        "Qual",
        "auf Grund",
        "ail",
        "kränklich",
        "ziellos",
        "lüftet",
        "Alarm",
        "alarmierend",
        "Alkoholismus",
        "Ausländer",
        "entfremden",
        "entfremdet",
        "Entfremdung",
        "Alimente",
        "Behauptung",
        "behaupten",
        "distanziert",
        "Auseinandersetzung",
        "mehrdeutig",
        "Hinterhalt",
        "Amnesie",
        "Amphetamine",
        "Anakonda",
        "anal",
        "Anarchismus",
        "Anarchist",
        "Anarchie",
        "Anathema",
        "Antike",
        "Zorn",
        "Angina",
        "Angeln",
        "wütend",
        "Pein",
        "Feindseligkeit",
        "Animus",
        "vernichten",
        "vernichtet",
        "Vernichtung",
        "Nerven",
        "Ärger",
        "nervig",
        "annullieren",
        "Aufhebung",
        "Anomalie",
        "anonym",
        "Antagonismus",
        "Gegner",
        "antagonistisch",
        "Milzbrand",
        "Antichrist",
        "Antipathie",
        "veraltet",
        "unsozial",
        "Antithese",
        "Angst",
        "Ängstlich",
        "Apache",
        "apathisch",
        "Apathie",
        "Blattlaus",
        "entsetzlich",
        "Appendizitis",
        "Auffassung",
        "besorgt",
        "Aneignung",
        "archaisch",
        "beschwerlich",
        "streiten",
        "Streit",
        "argumentativ",
        "trocken",
        "Rüstungen",
        "Anklage",
        "Verzug",
        "Festnahme",
        "Arroganz",
        "arrogant",
        "Arsen",
        "Brandstiftung",
        "Artillerie",
        "Asche",
        "beschämt",
        "Asche",
        "Arsch",
        "angreifen",
        "Angreifer",
        "Attentäter",
        "ermorden",
        "Ermordung",
        "Angriff",
        "Arschloch",
        "Irre",
        "adstringierend",
        "Asyl",
        "Atheismus",
        "Atherosklerose",
        "scheußlich",
        "Gräueltat",
        "Atrophie",
        "Attacke",
        "angreifend",
        "abgeschwächt",
        "Dämpfung",
        "Kühnheit",
        "streng",
        "Strenge",
        "autokratisch",
        "Autopsie",
        "Lawine",
        "Habsucht",
        "Rächer",
        "abgeneigt",
        "Abneigung",
        "vermeiden",
        "Vermeidung",
        "furchtbar",
        "Ungeschicklichkeit",
        "schief",
        "plappern",
        "plappernd",
        "Pavian",
        "rückwärts",
        "rückwärts",
        "Rückstau",
        "Bakterien",
        "NO TRANSLATION",
        "Schlecht",
        "Dachs",
        "schlecht",
        "Schlechtigkeit",
        "Gerichtsvollzieher",
        "Köder",
        "Ballen",
        "Balken",
        "NO TRANSLATION",
        "Bandit",
        "Fluch",
        "Knall",
        "Banger",
        "verbannen",
        "verbannt",
        "Verbannung",
        "Pleite",
        "Konkurs",
        "Banshee",
        "Widerhaken",
        "Barbar",
        "barbarisch",
        "Barbarei",
        "Borke",
        "gesperrt",
        "unfruchtbar",
        "Barrikade",
        "Barriere",
        "unbegründet",
        "Bastard",
        "Teig",
        "zerschlagen",
        "Batterie",
        "Schlacht",
        "kämpfte",
        "Schlachtfeld",
        "bawdy",
        "Bajonett",
        "Träger",
        "Tier",
        "bestialisch",
        "Prügel",
        "widerfahren",
        "bitten",
        "Bettler",
        "betteln",
        "Ungetüm",
        "verpflichtet",
        "verspätet",
        "schmälern",
        "kriegführend",
        "Gürtel",
        "Bieger",
        "Hinterbliebene",
        "Trauerfall",
        "beraubt",
        "Berserker",
        "Bestial",
        "verraten",
        "Verrat",
        "in acht nehmen",
        "verwirrt",
        "vorspannen",
        "voreingenommen",
        "Gezänk",
        "NO TRANSLATION",
        "Frömmler",
        "bigott",
        "Galle",
        "Biopsie",
        "Birke",
        "Geburtsort",
        "Hündin",
        "beißen",
        "bitterlich",
        "Bitterkeit",
        "bizarr",
        "schwarz",
        "Blackjack",
        "Erpressung",
        "Schwärze",
        "Schuld",
        "fade",
        "blasphemisch",
        "Blasphemie",
        "sprengen",
        "eklatant",
        "quasseln",
        "Feuer",
        "düster",
        "Blutung",
        "Makel",
        "Trockenfäule",
        "verdorben",
        "blind",
        "verblendet",
        "blindlings",
        "Blindheit",
        "Blase",
        "aufgebläht",
        "Klecks",
        "Blockade",
        "Blutvergießen",
        "blutrünstig",
        "blutig",
        "Fleck",
        "Gebläse",
        "auspusten",
        "Blues",
        "Bluff",
        "Schnitzer",
        "verwischen",
        "verschwommen",
        "erröten",
        "Prahlerei",
        "Moor",
        "gefälscht",
        "Kochen",
        "Standardplatte",
        "Bombe",
        "bombardieren",
        "Bombardierung",
        "bombardiert",
        "Knechtschaft",
        "Fesseln",
        "Buh",
        "Tölpel",
        "saufen",
        "NO TRANSLATION",
        "Langeweile",
        "langweilig",
        "Kreditnehmer",
        "Mühe",
        "störend",
        "Unterseite",
        "gebunden",
        "Kampf",
        "Rinder-",
        "Junge",
        "Boykott",
        "prahlen",
        "Brandy",
        "Draufgängertum",
        "Schlägerei",
        "dreist",
        "Bruch",
        "Nervenzusammenbruch",
        "halsbrecherisch",
        "NO TRANSLATION",
        "Bestechung",
        "Bestechung",
        "Brigade",
        "Schwefel",
        "Borste",
        "Breitseite",
        "grillen",
        "Pleite",
        "gebrochen",
        "Bordell",
        "Prellung",
        "Hauptlast",
        "brutal",
        "Brutalität",
        "Tier",
        "Buffet",
        "Fehler",
        "NO TRANSLATION",
        "bauchig",
        "Bully",
        "Gammler",
        "beschimpfen",
        "belastend",
        "Bürokratie",
        "Bürokrat",
        "Einbrecher",
        "Einbruch",
        "Beerdigung",
        "begraben",
        "Burke",
        "verbrannt",
        "Gehackt",
        "Metzger",
        "Hintern",
        "summte",
        "Kabale",
        "Kakophonie",
        "cad",
        "Leiche",
        "Käfig",
        "Berechnung",
        "NO TRANSLATION",
        "Anrufe",
        "Kampagnen",
        "stornieren",
        "Krebs",
        "Krebs",
        "Kannibale",
        "Kannibalismus",
        "NO TRANSLATION",
        "gefangen",
        "Gefangenschaft",
        "Fänger",
        "Erfassung",
        "Karkasse",
        "Karzinom",
        "Kardiomyopathie",
        "Nachlässigkeit",
        "Karikatur",
        "Karies",
        "Gemetzel",
        "fleischlich",
        "fleischfressende",
        "Kartell",
        "Fall",
        "Schatulle",
        "Kaste",
        "Unfallopfer",
        "Katarakt",
        "Katastrophe",
        "Katheter",
        "Vorsicht",
        "abtreten",
        "Friedhof",
        "zensieren",
        "Tadel",
        "Höre",
        "Einstellung",
        "Spreu",
        "Scheuern",
        "Ärger",
        "Herausforderung",
        "Chaos",
        "chaotisch",
        "Farce",
        "gebührenpflichtig",
        "Verfolgungsjagd",
        "Züchtigung",
        "gesprächig",
        "billig",
        "betrügen",
        "Käsekuchen",
        "Schikane",
        "kindisch",
        "kühl",
        "Chloroform",
        "Choke",
        "Cholera",
        "hacken",
        "lästig",
        "chronisch",
        "Zigarette",
        "Geschrei",
        "Zusammenstoß",
        "kollidierende",
        "Klaue",
        "Kloster",
        "getrübt",
        "Trübung",
        "Büschel",
        "ungeschickt",
        "Kokain",
        "zwingen",
        "Zwang",
        "Sarg",
        "kalt",
        "kalt",
        "Kälte",
        "Kolik",
        "Zusammenbruch",
        "Kollision",
        "Absprache",
        "Koma",
        "komatös",
        "Kampf",
        "Kämpfer",
        "kämpferisch",
        "Einlieferung",
        "Aufregung",
        "Kommunismus",
        "Kommunist",
        "Wettbewerb",
        "beschweren",
        "Beschwerde",
        "komplexiert",
        "Komplexität",
        "komplizieren",
        "kompliziert",
        "Komplikation",
        "Kompost",
        "Zwang",
        "verpflichtend",
        "verbergen",
        "verborgen",
        "Verstecken",
        "Einbildung",
        "eingebildet",
        "Gehirnerschütterung",
        "verurteilen",
        "Verurteilung",
        "herablassend",
        "Herablassung",
        "Bekenntnis",
        "beschränken",
        "beschränkt",
        "Beschränkung",
        "beschlagnahmen",
        "Beschlagnahme",
        "Feuersbrunst",
        "Konflikt",
        "in Konflikt",
        "verwechseln",
        "verwirrt",
        "verwechseln",
        "Verwechslung",
        "Stau",
        "beschwörend",
        "Eroberung",
        "Verschwörer",
        "verschwören sich",
        "Bestürzung",
        "Verstopfung",
        "einschränken",
        "eingeschränkt",
        "Zwang",
        "Ansteckung",
        "ansteckend",
        "verunreinigen",
        "kontaminiert",
        "Kontamination",
        "Verachtung",
        "verächtlich",
        "verächtlich",
        "strittig",
        "Schmuggelware",
        "Vertrag abgeschlossen",
        "widersprechen",
        "Widerspruch",
        "widersprüchlich",
        "Gegenteil",
        "kontrastiert",
        "verstoßen",
        "Zuwiderhandlung",
        "umstritten",
        "Kontroverse",
        "überführen",
        "Überzeugung",
        "Stall",
        "Kopieren",
        "Nachahmer",
        "Gerichtsmediziner",
        "Korporal",
        "Leiche",
        "Korrektur",
        "Korrosion",
        "ätzend",
        "korrupt",
        "korrumpierend",
        "Korruption",
        "Husten",
        "Berater",
        "Coursing",
        "begehren",
        "Feigling",
        "Feigheit",
        "feige",
        "mürrisch",
        "Riss",
        "geknackt",
        "knackend",
        "Krampf",
        "eng",
        "Kurbel",
        "verschroben",
        "Mist",
        "Absturz",
        "kriechen",
        "verrückt",
        "verrückt",
        "Knarren",
        "Kreatur",
        "Schleich",
        "Kriminalität",
        "Kriminelle",
        "Kriminalität",
        "kriechen",
        "Krüppel",
        "verkrüppelt",
        "Krise",
        "knackig",
        "Kritiker",
        "Kritik",
        "kritisieren",
        "Gauner",
        "Kreuz",
        "hockend",
        "Kreuzband",
        "Kreuzigung",
        "grobe",
        "grausam",
        "grausam",
        "Grausamkeit",
        "zerbröckelnd",
        "knirschen",
        "Kreuzzug",
        "zerdrückt",
        "zerkleinernd",
        "knusprig",
        "Schrei",
        "Weinen",
        "Krypta",
        "Hahnrei",
        "Kuckuck",
        "aussortieren",
        "Schuld",
        "schuldhaft",
        "Täter",
        "Kult",
        "schwerfällig",
        "Schröpfen",
        "Cur",
        "Fluch",
        "verflucht",
        "Fluchen",
        "flüchtig",
        "Cutter",
        "Halsabschneider",
        "Schneiden",
        "Zyanid",
        "Zyklon",
        "Zyste",
        "Zytomegalievirus",
        "plantschen",
        "Dämon",
        "bekloppt",
        "Dolch",
        "Beschädigung",
        "Schäden",
        "Verdammt",
        "Verdammnis",
        "verdammt",
        "Dämpfer",
        "Schuppen",
        "Dandy",
        "Achtung",
        "gefährlich",
        "verdunkeln",
        "verdunkelt",
        "Dunkelheit",
        "gestrichelt",
        "heimtückisch",
        "benommen",
        "deaktivieren",
        "Sackgasse",
        "tötlich",
        "taub",
        "Tod",
        "Debakel",
        "Ausschweifung",
        "Trümmer",
        "Schuld",
        "Schuldner",
        "zerfallen",
        "verfallen",
        "Verstorbene",
        "Betrug",
        "betrügerisch",
        "täuschen",
        "betrogen",
        "täuschen",
        "Täuschung",
        "trügerisch",
        "Deklination",
        "Ablehnen",
        "rückläufig",
        "Zersetzung",
        "verringern",
        "Dekrement",
        "altersschwach",
        "schreien",
        "abziehen",
        "Diffamierung",
        "verleumderisch",
        "Standard",
        "Niederlage",
        "besiegt",
        "Defekt",
        "NO TRANSLATION",
        "defekt",
        "wehrlos",
        "Aufschub",
        "Trotz",
        "trotzig",
        "Mangel",
        "Defizit",
        "entleeren",
        "Deflation",
        "verformen",
        "deformiert",
        "Deformität",
        "betrügen",
        "aufgegeben",
        "trotzen",
        "Entartung",
        "degenerieren",
        "Degradierung",
        "degradieren",
        "erniedrigend",
        "verzögern",
        "verspätet",
        "schädlich",
        "Streichung",
        "Kriminalität",
        "Delinquent",
        "phantasierend",
        "Delirium",
        "Sintflut",
        "Täuschung",
        "wahnhaft",
        "Nachfrage",
        "Anspruchsvoll",
        "wahnsinnig",
        "Demenz",
        "Ableben",
        "zerstören",
        "Abriss",
        "Dämon",
        "dämonisch",
        "demoralisiert",
        "Verweigerung",
        "verweigert",
        "anprangern",
        "Denunziation",
        "verweigern",
        "bestreiten",
        "abgereist",
        "Abfahrt",
        "Abhängigkeit",
        "Abhängigkeit",
        "beklagenswert",
        "bedauern",
        "deportieren",
        "Abschiebung",
        "verdorben",
        "Verderbtheit",
        "abwerten",
        "abgeschrieben",
        "Abschreibung",
        "drücken",
        "deprimiert",
        "deprimierend",
        "Depression",
        "depressiv",
        "Entbehrung",
        "geistesgestört",
        "verfallen",
        "Spott",
        "Ausnahmeregelung",
        "herabwürdigend",
        "Entweihung",
        "Wüste",
        "verlassen",
        "Desertion",
        "unterlassen",
        "Verwüstung",
        "Verzweiflung",
        "verzweifelt",
        "verzweifelt",
        "Verabscheuungswürdig",
        "NO TRANSLATION",
        "despotisch",
        "Despotismus",
        "mittellos",
        "zerstört",
        "Zerstörer",
        "zerstörend",
        "Zerstörung",
        "destruktiv",
        "Ablösung",
        "aufhalten",
        "Häftling",
        "Haft",
        "verschlechtern",
        "verschlechtert",
        "Verschlechterung",
        "verabscheuen",
        "detonieren",
        "ablenken",
        "Nachteil",
        "schädlich",
        "Detritus",
        "verwüsten",
        "verheerend",
        "Verwüstung",
        "Teufel",
        "teuflisch",
        "Verschwunden",
        "Übertragung",
        "verschlingen",
        "teuflisch",
        "Diagnose",
        "Schmährede",
        "Diktator",
        "diktatorisch",
        "Diktatur",
        "NO TRANSLATION",
        "Schwierigkeiten",
        "Schwierigkeit",
        "abschweifen",
        "baufällig",
        "verdünnen",
        "verringern",
        "abgebaut",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "Schmutz",
        "dreckig",
        "Behinderung",
        "deaktivieren",
        "behindert",
        "unzufrieden",
        "nicht zustimmen",
        "nicht einverstanden",
        "Uneinigkeit",
        "nicht erlaubt",
        "enttäuschen",
        "enttäuscht",
        "enttäuschend",
        "Enttäuschung",
        "Missbilligung",
        "missbilligen",
        "abgelehnt",
        "missbilligend",
        "Katastrophe",
        "katastrophal",
        "bezweifle",
        "Rückwürfe",
        "entladen",
        "Disziplin",
        "ablehnen",
        "Verfärbung",
        "verfärbt",
        "Beschwerden",
        "trennen",
        "getrennt",
        "Trennung",
        "Unzufriedenheit",
        "abbrechen",
        "Diskontinuität",
        "Zwietracht",
        "entmutigen",
        "Entmutigung",
        "diskreditieren",
        "diskriminieren",
        "diskriminierend",
        "Diskriminierung",
        "Verachtung",
        "Krankheit",
        "krank",
        "körperlos",
        "Abkopplung",
        "entstellt",
        "Schande",
        "NO TRANSLATION",
        "schändlich",
        "verärgert",
        "der Ekel",
        "widerlich",
        "entmutigt",
        "entmutigend",
        "unehrlich",
        "Unehrlichkeit",
        "entehren",
        "Ernüchterung",
        "Desinformation",
        "unaufrichtig",
        "zerfallen",
        "Zerfall",
        "desinteressiert",
        "nicht gefallen",
        "missfiel",
        "ausgerenkt",
        "düster",
        "Bestürzung",
        "Zerstückelung",
        "Entlassung",
        "Ungehorsam",
        "ungehorsam",
        "ungehorsam",
        "Störung",
        "ungeordnet",
        "unorganisiert",
        "verunglimpfen",
        "verächtlich",
        "Ungleichheit",
        "leidenschaftslos",
        "zerstreuen",
        "Dispersion",
        "verdrängen",
        "unzufrieden",
        "Unmut",
        "Verfügung",
        "enteignet",
        "Streit",
        "Disqualifikation",
        "disqualifiziert",
        "disqualifizieren",
        "außer Acht lassen",
        "missachtet",
        "anrüchig",
        "Respektlosigkeit",
        "respektlos",
        "Störung",
        "Unzufriedenheit",
        "Uneinigkeit",
        "abweichend",
        "Bärendienst",
        "Dissident",
        "Auflösung",
        "Dissonanz",
        "Abneigung",
        "geschmacklos",
        "verzerrt",
        "Verzerrung",
        "ablenken",
        "abgelenkt",
        "ablenkend",
        "Ablenkung",
        "verstört",
        "Not",
        "betrübt",
        "quälend",
        "Misstrauen",
        "Störung",
        "gestört",
        "Nichtgebrauch",
        "stillgelegt",
        "abweichend",
        "veräussert",
        "Veräußerung",
        "Scheidung",
        "Schwindel",
        "schwindlig",
        "angedockt",
        "NO TRANSLATION",
        "Flaute",
        "Dole",
        "NO TRANSLATION",
        "Dominant",
        "Herrschaft",
        "Esel",
        "Gekritzel",
        "Untergang",
        "verurteilt",
        "Weltuntergang",
        "Zweifel",
        "zweifelhaft",
        "zweifeln",
        "Dusche",
        "dürftig",
        "Untergang",
        "eintönig",
        "Drainage",
        "Nachteil",
        "fürchten",
        "schrecklich",
        "schrecklich",
        "trostlos",
        "Trinken",
        "Gefasel",
        "Drohne",
        "hängend",
        "Dürre",
        "ertrinken",
        "Schläfrigkeit",
        "Plackerei",
        "betrunken",
        "Trunkenheit",
        "zweifelhaft",
        "Stumpf",
        "Dumm",
        "Attrappe",
        "Dumps",
        "Dun",
        "Verlies",
        "täuschen",
        "Duplizität",
        "Zwang",
        "Staub",
        "zwergenhaft",
        "sterben",
        "Ruhr",
        "Erdbeben",
        "lauschen",
        "Edikt",
        "weibisch",
        "egoistisch",
        "ungeheuerlich",
        "auswerfen",
        "Auswurf",
        "Beseitigung",
        "schwer fassbar",
        "abgemagert",
        "NO TRANSLATION",
        "in Verlegenheit bringen",
        "peinlich",
        "Verlegenheit",
        "Unterschlagung",
        "Embolie",
        "verwickelt",
        "Notfall",
        "Enklave",
        "Eingriff",
        "Belastung",
        "gefährden",
        "gefährdet",
        "endemisch",
        "Feind",
        "Durchsetzung",
        "rätselhaft",
        "Feindschaft",
        "versklaven",
        "versklavt",
        "Versklavung",
        "verstrickt",
        "Verstrickung",
        "Eingeweide",
        "neidisch",
        "Epidemie",
        "Epilepsie",
        "ausrotten",
        "Ausrottung",
        "löschen",
        "Erosion",
        "err",
        "fehlgeleitet",
        "unberechenbar",
        "Erratum",
        "fehlerhaft",
        "Error",
        "ausbrechen",
        "Eruption",
        "eskalieren",
        "vermeiden",
        "Spionage",
        "entfremdet",
        "Euthanasie",
        "evakuieren",
        "Evakuierung",
        "ausweichen",
        "Ausweichen",
        "vertreiben",
        "Vertreibung",
        "böse",
        "verschärfen",
        "Exazerbation",
        "anspruchsvoll",
        "übertreiben",
        "übertrieben",
        "Untersuchung",
        "Verzweiflung",
        "Ausgrabung",
        "Überschuss",
        "Verbrauchssteuer",
        "ausgeschlossen",
        "ohne",
        "Ausschluss",
        "Kot",
        "quälend",
        "Ausrede",
        "Ausführung",
        "Henker",
        "Auspuff",
        "erschöpft",
        "Erschöpfung",
        "NO TRANSLATION",
        "Exil",
        "Exorzismus",
        "Expatriate",
        "vertreiben",
        "Ausgaben",
        "Kosten",
        "verfallen",
        "abgelaufen",
        "Kraftausdruck",
        "explodieren",
        "Explosion",
        "explosiv",
        "ausgesetzt",
        "Enteignung",
        "Vertreibung",
        "vernichten",
        "Vernichtung",
        "ausgestorben",
        "löschen",
        "außergerichtliche",
        "Extremität",
        "fabrizieren",
        "Herstellung",
        "verblassen",
        "Kot",
        "Versagen",
        "Fehler",
        "Ohnmacht",
        "treulos",
        "Fälschung",
        "fallen",
        "trügerisch",
        "Irrtum",
        "fehlbar",
        "fallend",
        "Brache",
        "Lüge",
        "fälschlicherweise",
        "Fälschung",
        "verfälschen",
        "Falschheit",
        "schwanken",
        "Hungersnot",
        "Fanatiker",
        "Farce",
        "Farcisch",
        "Fasten",
        "Fett",
        "tödlich",
        "Todesopfer",
        "Schicksal",
        "ermüden",
        "ermüdet",
        "fett",
        "Fehler",
        "Defekt",
        "Kitz",
        "Angst",
        "ängstlich",
        "ängstlich",
        "Angst",
        "fiebrig",
        "Kot",
        "Kot",
        "Gebühr",
        "schwach",
        "vorgetäuscht",
        "fiel",
        "Schwerverbrecher",
        "Verbrechen",
        "Ferment",
        "wütend",
        "Wildheit",
        "Fehde",
        "feudal",
        "Feudalismus",
        "fiebrig",
        "Fiasko",
        "Flunkerei",
        "wankelmütig",
        "fiktiv",
        "Teufel",
        "heftig",
        "Kampf",
        "Kampf",
        "obstruieren",
        "Schmutz",
        "schmutzig",
        "Feuerarme",
        "passt",
        "schlaff",
        "schlaff",
        "kennzeichnend",
        "flagrant",
        "Flocke",
        "Klappe",
        "Blähung",
        "zur Schau stellen",
        "Fehler",
        "Floh",
        "NO TRANSLATION",
        "Vlies",
        "fleischig",
        "zucken",
        "prügeln",
        "Flop",
        "Flunder",
        "Grippe",
        "Fluktuation",
        "Feind",
        "vereitelt",
        "Torheit",
        "Dummkopf",
        "töricht",
        "Torheit",
        "Futter",
        "Beutezug",
        "verbieten",
        "verbieten",
        "Macht",
        "gezwungen",
        "gewaltsam",
        "Ahnung",
        "ausschließen",
        "verzichten",
        "ausländisch",
        "Ausländer",
        "vorgewarnt",
        "einbüßen",
        "verwirkt",
        "Verwirkung",
        "Fälschung",
        "vergessen",
        "Vergessene",
        "verlassen",
        "formlos",
        "Unzucht",
        "verlassen",
        "verlassene",
        "Foul",
        "Fraktur",
        "zerbrechlich",
        "Gebrechlichkeit",
        "hektisch",
        "Betrug",
        "betrügerisch",
        "belastet",
        "Kampf",
        "ausgefranst",
        "verrückt",
        "Einfrieren",
        "frenetisch",
        "wütend",
        "Raserei",
        "Bund",
        "Schreck",
        "erschrecken",
        "erschrocken",
        "schrecklich",
        "kalt",
        "frivol",
        "Erfrierung",
        "Schaum",
        "Stirnrunzeln",
        "die Stirn runzelnd",
        "fruchtlos",
        "vereiteln",
        "frustriert",
        "Frustration",
        "Fudge",
        "Flüchtling",
        "fummeln",
        "Rauch",
        "rauchend",
        "Pilz",
        "Funk",
        "wütend",
        "Furor",
        "Wut",
        "Aufregung",
        "pingelig",
        "zwecklos",
        "Sinnlosigkeit",
        "gaby",
        "Gag",
        "Galle",
        "Galgen",
        "zocken",
        "Spieler",
        "Glücksspiel",
        "Gang",
        "Gefängnis",
        "Spalt",
        "Müll",
        "grell",
        "Garnierung",
        "klaffende",
        "keuchend",
        "NO TRANSLATION",
        "hager",
        "Herr",
        "geriatrisch",
        "grässlich",
        "Ghetto",
        "gespenstisch",
        "Kauderwelsch",
        "Glazial",
        "Blendung",
        "grell",
        "glib",
        "Düsternis",
        "düster",
        "dumpf",
        "Glut",
        "Völlerei",
        "Gnom",
        "Kobold",
        "gottlos",
        "Tripper",
        "Schmiere",
        "Blut",
        "Schlucht",
        "Gorilla",
        "blutig",
        "Klatsch",
        "Hohlkehle",
        "Gicht",
        "Regierung",
        "greifen",
        "greifend",
        "Gitter",
        "gerieben",
        "Gitter",
        "Grab",
        "Gier",
        "gierig",
        "Granate",
        "Trauer",
        "Beschwerde",
        "trauern",
        "schmerzhaft",
        "grimmig",
        "Schmutz",
        "schmutzig",
        "Mahlen",
        "grässlich",
        "Grizzly",
        "Stöhnen",
        "NO TRANSLATION",
        "brutto",
        "grotesk",
        "geerdet",
        "grundlos",
        "knurren",
        "knurrend",
        "Groll",
        "widerwillig",
        "grausam",
        "schroff",
        "murren",
        "mürrisch",
        "Guerilla",
        "List",
        "Guillotine",
        "Schuld",
        "schuldig",
        "Gestalt",
        "Möwe",
        "leichtgläubig",
        "Gewehr",
        "Schwall",
        "Fressen",
        "Zigeuner",
        "Hexe",
        "hager",
        "behaart",
        "auf halber Strecke",
        "Halluzination",
        "Halfter",
        "anhalten",
        "Korb",
        "lähmen",
        "Behinderung",
        "hängend",
        "Henker",
        "belästigen",
        "Vorbote",
        "gehärtet",
        "Härte",
        "Not",
        "Hure",
        "Schaden",
        "schädlich",
        "erschütternd",
        "harry",
        "Härte",
        "Hash",
        "Haschisch",
        "hastig",
        "Hass",
        "hasserfüllt",
        "hassend",
        "Hass",
        "hochmütig",
        "verfolgen",
        "spukt",
        "Verwüstung",
        "Gefahr",
        "gefährlich",
        "Dunst",
        "Kopfschmerzen",
        "berauschend",
        "Hören",
        "Hörensagen",
        "Leichenwagen",
        "Herzenskummer",
        "Sodbrennen",
        "herzlos",
        "Heiden-",
        "schwer",
        "Hacke",
        "erhöhen",
        "abscheulich",
        "Hölle",
        "höllisch",
        "hilflos",
        "Hilflosigkeit",
        "Blutung",
        "Hämorrhoiden",
        "Ketzerei",
        "Ketzer",
        "Zwitter",
        "Heroin",
        "Herpes",
        "Herpesvirus",
        "Zögern",
        "versteckt",
        "scheußlich",
        "behindernd",
        "Hindernis",
        "Hippie",
        "zischen",
        "zischend",
        "schlagen",
        "bisher",
        "Bienenstock",
        "heiser",
        "weiß",
        "Scherz",
        "Hobo",
        "Schwein",
        "hohl",
        "Holocaust",
        "obdachlos",
        "Heimweh",
        "mörderisch",
        "Mord",
        "Homosexualität",
        "Kapuze",
        "süchtig",
        "johlen",
        "hoffnungslos",
        "Hoffnungslosigkeit",
        "Horde",
        "schrecklich",
        "entsetzlich",
        "schrecklich",
        "schrecklich",
        "entsetzt",
        "erschreckend",
        "Grusel",
        "Schrecken",
        "Geisel",
        "feindlich",
        "Feindseligkeiten",
        "Feindseligkeit",
        "heulen",
        "sauer",
        "Humbug",
        "demütigen",
        "demütigend",
        "Erniedrigung",
        "Ahnung",
        "hungrig",
        "Jäger",
        "Jagd",
        "Hurrikan",
        "hastig",
        "verletzt",
        "verletzend",
        "weh",
        "Stricher",
        "Hydra",
        "Hydrozephalus",
        "Hype",
        "Hyperbel",
        "Heuchelei",
        "Heuchler",
        "heuchlerisch",
        "Hysterie",
        "hysterisch",
        "Idiotie",
        "Dummkopf",
        "idiotisch",
        "Leitrolle",
        "Götzendienst",
        "Ignoranz",
        "ignorant",
        "ignorieren",
        "krank",
        "illegal",
        "Rechtswidrigkeit",
        "unleserlich",
        "illegitim",
        "unerlaubt",
        "Analphabet",
        "Krankheit",
        "unlogisch",
        "Illusion",
        "imitiert",
        "Nachahmung",
        "unreif",
        "Unreife",
        "unmoralisch",
        "Unmoral",
        "beeinträchtigen",
        "Beeinträchtigung",
        "unpassierbar",
        "Ungeduld",
        "ungeduldig",
        "anklagen",
        "Anklage",
        "behindern",
        "Unvollkommenheit",
        "unvollkommen",
        "imitieren",
        "Identitätswechsel",
        "unerbittlich",
        "implizieren",
        "unhöflich",
        "Verhängung",
        "unmöglich",
        "Impotenz",
        "impotent",
        "beschlagnahmen",
        "undurchführbar",
        "einsperren",
        "eingesperrt",
        "Haft",
        "Unschicklichkeit",
        "unklug",
        "unrein",
        "Verunreinigung",
        "Imputation",
        "Unfähigkeit",
        "nicht zugänglich",
        "ungenau",
        "Untätigkeit",
        "Inaktivität",
        "Unzulänglichkeit",
        "unzureichend",
        "unzulässig",
        "albern",
        "nicht anwendbar",
        "unangemessen",
        "Unaufmerksamkeit",
        "unverständlich",
        "unkalkulierbar",
        "Unfähigkeit",
        "Einkerkerung",
        "im Fall",
        "Brandsätze",
        "Weihrauch",
        "unaufhörlich",
        "Inzest",
        "inzestuös",
        "Verbrennung",
        "anregen",
        "unfreundlich",
        "inkohärent",
        "unvereinbar",
        "Inkompetenz",
        "inkompetent",
        "Unvollständigkeit",
        "unverständlich",
        "unpassend",
        "belanglos",
        "rücksichtslos",
        "Inkonsistenz",
        "ungünstig",
        "falsch",
        "ungläubig",
        "Belästigung",
        "Inkubus",
        "eingehen",
        "unheilbar",
        "Einfall",
        "unanständig",
        "Unentschlossenheit",
        "unentschlossen",
        "unhaltbar",
        "entschädigen",
        "Vertrag",
        "unbestimmt",
        "anklagen",
        "Anklage",
        "Gleichgültigkeit",
        "bedürftig",
        "empört",
        "Empörung",
        "undeutlich",
        "Indoktrination",
        "träge",
        "unwirksam",
        "unwirksam",
        "Ineffizienz",
        "ineffizient",
        "ungeschickt",
        "Unbeholfenheit",
        "Ungleichheit",
        "ungerecht",
        "inert",
        "unentschuldbar",
        "NO TRANSLATION",
        "unerfahren",
        "unerklärlich",
        "berüchtigt",
        "Schande",
        "Kindestötung",
        "infantil",
        "Infarkt",
        "infizieren",
        "Infektion",
        "ansteckend",
        "minderwertig",
        "Minderwertigkeit",
        "Inferno",
        "Unfruchtbarkeit",
        "Befall",
        "ungläubig",
        "Untreue",
        "gebrechlich",
        "Gebrechen",
        "Entzündung",
        "aufgeblasen",
        "Inflation",
        "zufügen",
        "Zufügung",
        "Grippe",
        "Informant",
        "Übertretung",
        "selten",
        "Verletzung",
        "hemmen",
        "unwirtlich",
        "unmenschlich",
        "Unmenschlichkeit",
        "feindlich",
        "Ungerechtigkeit",
        "einstweilige Verfügung",
        "verletzen",
        "verletzt",
        "schädlich",
        "Verletzung",
        "Ungerechtigkeit",
        "Insasse",
        "unwirksam",
        "wahnsinnig",
        "Wahnsinn",
        "unsicher",
        "Unsicherheit",
        "heimtückisch",
        "Bedeutungslosigkeit",
        "unbedeutend",
        "fade",
        "frech",
        "Insolvenz",
        "zahlungsunfähig",
        "Instabilität",
        "anstiften",
        "Anstiftung",
        "Insuffizienz",
        "unzureichend",
        "ungenügend",
        "Beleidigung",
        "beleidigend",
        "Aufständische",
        "unüberwindbar",
        "Aufstand",
        "Inter",
        "Verbot",
        "Interferenz",
        "Begräbnis",
        "unterbrechen",
        "unterbrochen",
        "Arzt",
        "einschüchtern",
        "Einschüchterung",
        "unerträglich",
        "Intoleranz",
        "intolerant",
        "berauscht",
        "hartnäckig",
        "Intrigen",
        "Eindringling",
        "Einbruch",
        "aufdringlich",
        "einfallen",
        "Eindringling",
        "ungültig machen",
        "Ungültigkeitserklärung",
        "Nichtigkeit",
        "Invasion",
        "unfreiwillig",
        "Involution",
        "wütend",
        "NO TRANSLATION",
        "Eisen",
        "irrational",
        "Irrationalität",
        "unvereinbar",
        "irregulär",
        "Unregelmäßigkeit",
        "irrelevant",
        "nicht reparierbar",
        "unverantwortlich",
        "respektlos",
        "unwiderruflich",
        "Reizbarkeit",
        "reizbar",
        "irritierend",
        "Reizung",
        "isoliert",
        "Isolierung",
        "quasseln",
        "Gefängnis",
        "Jargon",
        "erschütternd",
        "Gelbsucht",
        "eifersüchtig",
        "Eifersucht",
        "gefährden",
        "Gefahr",
        "John",
        "Scherz",
        "NO TRANSLATION",
        "Durcheinander",
        "Müll",
        "Junta",
        "jugendlich",
        "Kern",
        "Kick",
        "entführen",
        "töten",
        "Tötung",
        "Drachen",
        "Totenglocke",
        "verknotet",
        "arbeitete",
        "mühsam",
        "Labyrinth",
        "Mangel",
        "fehlend",
        "glanzlos",
        "beladen",
        "Verzögerung",
        "rückständig",
        "Höhle",
        "Klage",
        "Erdrutsch",
        "matt",
        "schmachten",
        "schmachtend",
        "Ablauf",
        "Diebstahl",
        "Peitsche",
        "spät",
        "Verspätung",
        "latent",
        "Latrinen",
        "lächerlich",
        "Lava",
        "Gesetzlosigkeit",
        "Klage",
        "Anwalt",
        "lax",
        "Abführmittel",
        "faul",
        "Leck",
        "Leckage",
        "undicht",
        "verlassen",
        "Blutegel",
        "Blutegel",
        "NO TRANSLATION",
        "Zitrone",
        "Lepra",
        "lesbisch",
        "verringern",
        "geringer",
        "tödlich",
        "Lethargie",
        "Leukämie",
        "erheben",
        "Lewd",
        "Liaison",
        "Lügner",
        "Verleumdung",
        "lecken",
        "Lüge",
        "leblos",
        "begrenzt",
        "schlaff",
        "Fussel",
        "Alkohol",
        "lustlos",
        "Prozesspartei",
        "prozessieren",
        "Rechtsstreitigkeiten",
        "prozessual",
        "Wurf",
        "livid",
        "Laib",
        "Bummler",
        "NO TRANSLATION",
        "verabscheuen",
        "Abscheu",
        "abscheulich",
        "Lobbyist",
        "NO TRANSLATION",
        "Heuschrecke",
        "erhaben",
        "Einsamkeit",
        "einsam",
        "einsam",
        "Klo",
        "Webstuhl",
        "Loon",
        "verrückt",
        "Beute",
        "verlieren",
        "verlieren",
        "Verlust",
        "hat verloren",
        "Lautstärke",
        "Salon",
        "Laus",
        "niedriger",
        "Senkung",
        "niedrigste",
        "Tiefland",
        "niedrig",
        "lächerlich",
        "lumbering",
        "Klumpen",
        "klumpig",
        "Wahnsinn",
        "verrückt",
        "Stich",
        "locken",
        "grimmig",
        "lauern",
        "lauernd",
        "üppig",
        "Lust",
        "lustvoll",
        "liegend",
        "lynchen",
        "Keule",
        "wütend",
        "verrückt machen",
        "Verrückter",
        "Wahnsinn",
        "Mafia",
        "Made",
        "behelfsmäßig",
        "Krankheit",
        "Unwohlsein",
        "Malaria",
        "böswillig",
        "Amtsuntreue",
        "Missbildung",
        "Bosheit",
        "böswillig",
        "verleumden",
        "Malignität",
        "maligne",
        "Fehlverhalten",
        "Mandamus",
        "NO TRANSLATION",
        "Mangel",
        "Manie",
        "Wahnsinniger",
        "wahnsinnig",
        "manipulieren",
        "Manipulation",
        "Totschlag",
        "düngen",
        "beschädigen",
        "Spanne",
        "kastanienbraun",
        "Martingal",
        "Märtyrer",
        "Martyrium",
        "Masochismus",
        "Massaker",
        "Materialismus",
        "Materialist",
        "schlängelt sich",
        "bedeutungslos",
        "Masern",
        "einmischen",
        "mittelmäßig",
        "Mittelmäßigkeit",
        "melancholisch",
        "Melancholie",
        "Nahkampf",
        "Melodrama",
        "Kernschmelze",
        "Bedrohung",
        "bedrohlich",
        "niedrig",
        "Söldner",
        "gnadenlos",
        "Chaos",
        "unordentlich",
        "Metastasierung",
        "Methanol",
        "Mehltau",
        "Miliz",
        "Mimikry",
        "minimieren",
        "Minimum",
        "Minderheit",
        "NO TRANSLATION",
        "Fehlverhalten",
        "Fehlgeburt",
        "Unfug",
        "boshaft",
        "Missverständnis",
        "Fehlverhalten",
        "elend",
        "kläglich",
        "Elend",
        "Unglück",
        "fehlgeleitet",
        "Missgeschick",
        "Fehlinterpretation",
        "irreführen",
        "irreführend",
        "Misswirtschaft",
        "Nichtübereinstimmung",
        "falsch benennen",
        "verlegen",
        "verlegt",
        "falsch darstellen",
        "Falschdarstellung",
        "falsch dargestellt",
        "fehlt",
        "Falschangabe",
        "Fehler",
        "falsch",
        "Herrin",
        "NO TRANSLATION",
        "missverstehen",
        "Missverständnis",
        "Missbrauch",
        "Milbe",
        "Mob",
        "Spott",
        "Verspottung",
        "Belästigung",
        "einfarbig",
        "Monopolist",
        "Monsun",
        "Monster-",
        "Ungeheuerlichkeit",
        "launisch",
        "moot",
        "morbid",
        "Morbidität",
        "Leichenschauhaus",
        "moribund",
        "Trottel",
        "schwachsinnig",
        "Bissen",
        "sterblich",
        "Mortalität",
        "Demütigung",
        "Leichenhalle",
        "Moskito",
        "trauern",
        "traurig",
        "Trauer",
        "Dreck",
        "Schlamm",
        "Durcheinander",
        "verwirrt",
        "schlammig",
        "Muff",
        "Maultier",
        "Mama",
        "murmeln",
        "Mumps",
        "Mord",
        "Mörder",
        "mörderisch",
        "trübe",
        "NO TRANSLATION",
        "muffig",
        "Mutant",
        "verstümmelt",
        "Verstümmelung",
        "Meuterei",
        "NO TRANSLATION",
        "Schnauze",
        "Kurzsichtigkeit",
        "schnappen",
        "Nadir",
        "NO TRANSLATION",
        "naiv",
        "namenlos",
        "Windel",
        "Betäubungsmittel",
        "böse",
        "frech",
        "Übelkeit",
        "übel",
        "NO TRANSLATION",
        "notwendig",
        "Bedürftige",
        "schändlich",
        "Negation",
        "Negativ",
        "vernachlässigen",
        "vernachlässigt",
        "Vernachlässigung",
        "Fahrlässigkeit",
        "fahrlässig",
        "NO TRANSLATION",
        "Neger",
        "Vetternwirtschaft",
        "nervös",
        "unter",
        "Nessel",
        "Neuralgie",
        "Neurose",
        "neurotisch",
        "Nikotin",
        "Nigger",
        "Albtraum",
        "Nihilismus",
        "Lärm",
        "laut",
        "NO TRANSLATION",
        "Unsinn",
        "unsinnig",
        "Schlinge",
        "Nichts",
        "schädlich",
        "Ärgernis",
        "NO TRANSLATION",
        "zunichte machen",
        "betäuben",
        "Taubheit",
        "NO TRANSLATION",
        "Scherz",
        "fettleibig",
        "Fettleibigkeit",
        "Obi",
        "ob",
        "Nachruf",
        "Einwand",
        "anstößig",
        "verpflichten",
        "Schuldner",
        "auslöschen",
        "ausgelöscht",
        "Auslöschung",
        "Vergessenheit",
        "widerlich",
        "obszön",
        "Obszönität",
        "Dunkelheit",
        "Hindernis",
        "hartnäckig",
        "behindern",
        "Obstruktion",
        "hinderlich",
        "stumpf",
        "Okkulte",
        "Kuriosität",
        "abscheulich",
        "Geruch",
        "beleidigen",
        "beleidigt",
        "Täter",
        "Delikt",
        "beleidigend",
        "beiläufig",
        "abziehend",
        "Oger",
        "olfaktorisch",
        "Oligarchie",
        "Omen",
        "ominös",
        "auslassen",
        "belastend",
        "Last",
        "Schlamm",
        "undurchsichtig",
        "Opern",
        "Opiate",
        "rechthaberisch",
        "Opium",
        "Gegner",
        "ablehnen",
        "entgegengesetzt",
        "Opposition",
        "unterdrücken",
        "Unterdrückung",
        "drückend",
        "Unterdrücker",
        "Ork",
        "Tortur",
        "Artillerie",
        "Waise",
        "angeblich",
        "verdrängen",
        "ausgestoßen",
        "Aufschrei",
        "Nebengebäude",
        "ausgefallen",
        "verbieten",
        "Empörung",
        "Ovation",
        "anmaßend",
        "Überladung",
        "bedeckt",
        "übertreiben",
        "Überdosis",
        "überfällig",
        "überschätzt",
        "Überlauf",
        "überwuchert",
        "Überlast",
        "überbezahlt",
        "überwältigen",
        "überwältigend",
        "überteuert",
        "Aufsicht",
        "Sturz",
        "umstürzen",
        "überwältigen",
        "überwältigt",
        "geschuldet",
        "Oxidation",
        "Schmerzen",
        "schmerzt",
        "schmerzlich",
        "schmerzlich",
        "Schmerzen",
        "Lähmung",
        "Pandemie",
        "NO TRANSLATION",
        "Panik",
        "Lähmung",
        "gelähmt",
        "Paranoia",
        "Parasit",
        "NO TRANSLATION",
        "Papagei",
        "sparsam",
        "Partisan",
        "NO TRANSLATION",
        "passiv",
        "Passivität",
        "Patch",
        "erbärmlich",
        "bevormundend",
        "NO TRANSLATION",
        "Mangel",
        "Pauper",
        "Pfand",
        "Rückzahlung",
        "Zahlung",
        "Besonderheiten",
        "Fußgänger",
        "strafbar",
        "Elfmeter",
        "Penetration",
        "Zuchthaus",
        "Verderben",
        "Tücke",
        "gefährlich",
        "umkommen",
        "verderblich",
        "umgekommen",
        "verderblich",
        "Meineid",
        "verderblich",
        "Täter",
        "Verewigung",
        "verwirrt",
        "Verwirrung",
        "verfolgen",
        "Verfolgung",
        "Störung",
        "Keuchhusten",
        "pervers",
        "Perversion",
        "pervers",
        "pervertiert",
        "Pessimismus",
        "Pessimist",
        "Pest",
        "Pest",
        "Haustier",
        "kleinlich",
        "Phantom",
        "Schleim",
        "gefälscht",
        "Streikposten",
        "Streikposten",
        "Essiggurke",
        "Schwein",
        "Taube",
        "Pfähle",
        "plündern",
        "Zuhälter",
        "Pickel",
        "Kiefer",
        "Ritzel",
        "Pique",
        "Piraterie",
        "Pirat",
        "Pistole",
        "Falle",
        "Plagiat",
        "Pest",
        "Kläger",
        "überzogen",
        "Spieler",
        "Plädoyer",
        "Notlage",
        "plodding",
        "Lot",
        "Plunder",
        "stürzen",
        "Lungenentzündung",
        "Wilderei",
        "zwecklos",
        "Gift",
        "vergiftet",
        "Vergiftung",
        "giftig",
        "Sack",
        "Polemik",
        "Polio",
        "verschmutzen",
        "Verschmutzung",
        "Polygamie",
        "Pomp",
        "pompös",
        "schwerfällig",
        "schlecht",
        "Pop",
        "Stachelschwein",
        "Porno",
        "porno",
        "pornografisch",
        "Pornographie",
        "Pose",
        "besessen",
        "Besitz",
        "posthum",
        "Verschiebung",
        "Pfund",
        "Armut",
        "machtlos",
        "Streich",
        "prekär",
        "Bezirk",
        "räuberisch",
        "Dilemma",
        "Schwangerschaft",
        "Vorurteil",
        "voreingenommen",
        "nachteilig",
        "vorsätzlich",
        "Druck",
        "anmaßend",
        "so tun als ob",
        "vorgetäuscht",
        "vortäuschend",
        "vortäuschen",
        "Vorsätze",
        "präventiv",
        "Beute",
        "Stechen",
        "stachelig",
        "Gefängnis",
        "Häftling",
        "eingeweiht",
        "Problem",
        "zögern",
        "Aufschub",
        "entweihen",
        "Profanität",
        "Fülle",
        "verboten",
        "Verbot",
        "verlängern",
        "Promiscuous",
        "Propaganda",
        "strafrechtlich verfolgen",
        "Strafverfolgung",
        "Prostituierte",
        "Prostitution",
        "Provokation",
        "provozierend",
        "neugierig sein",
        "neugierig",
        "Psychose",
        "Publizist",
        "geschwollen",
        "schlagen",
        "scharf",
        "bestrafen",
        "bestraft",
        "bestrafen",
        "Bestrafung",
        "strafend",
        "Fegefeuer",
        "Säuberung",
        "Eiter",
        "Quacksalber",
        "Sumpf",
        "Wachtel",
        "Dilemma",
        "Streit",
        "quash",
        "unterdrücken",
        "fraglich",
        "Quecksilber",
        "Verlassen",
        "Köcher",
        "Zittern",
        "Quiz",
        "Pöbel",
        "tollwütig",
        "Tollwut",
        "Gestell",
        "Schläger",
        "Strahlung",
        "radioaktiv",
        "Radon",
        "Rage",
        "wütend",
        "Lumpen",
        "Überfall",
        "Schiene",
        "RAM",
        "weitschweifend",
        "Amoklauf",
        "ranzig",
        "Lösegeld",
        "vergewaltigen",
        "Greifvögel",
        "Schlingel",
        "Ausschlag",
        "Ratte",
        "Bewertung",
        "rauh",
        "gefräßig",
        "rasend",
        "reaktionär",
        "Rückseite",
        "Rebell",
        "Tadel",
        "widerlegen",
        "widerspenstig",
        "Rezession",
        "Rückfälligkeit",
        "leichtsinnig",
        "Leichtsinn",
        "redundant",
        "Reflux",
        "feuerfest",
        "Ablehnung",
        "sich weigern",
        "verweigert",
        "Regress",
        "Regression",
        "Bedauern",
        "bedauerlich",
        "bereut",
        "bereuen",
        "regulatorisch",
        "Zügel",
        "ablehnen",
        "abgelehnt",
        "Ablehnung",
        "lehnt ab",
        "Rückfall",
        "Abstieg",
        "verzichten",
        "widerstrebend",
        "Untersuchungshaft",
        "Abhilfe",
        "nachlässig",
        "Reue",
        "Entfernung",
        "Löschen",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "Renegat",
        "verzichten",
        "Verzicht",
        "NO TRANSLATION",
        "abweisend",
        "abstoßend",
        "unterdrücken",
        "Repression",
        "Verweis",
        "Abdruck",
        "Repressalie",
        "Vorwurf",
        "Republik",
        "Zurückweisung",
        "Abstoßung",
        "zurücktreten",
        "Rücktritt",
        "verleumdet",
        "nachtragend",
        "Groll",
        "zurücktreten",
        "Rücktritt",
        "resigniert",
        "widerstehen",
        "Widerstand",
        "beständig",
        "Widerstand",
        "zurückhalten",
        "beschränken",
        "Beschränkung",
        "restriktiv",
        "zurückschlagen",
        "Vergeltung",
        "Vergeltung",
        "verzögern",
        "Verzögerung",
        "zurückhaltend",
        "Retorte",
        "einfahren",
        "Rückzug",
        "Einsparungen",
        "Vergeltung",
        "rückläufig",
        "Rache",
        "Umkehrung",
        "Widerruf",
        "widerrufen",
        "Revolte",
        "empörend",
        "Revolver",
        "Abscheu",
        "Rheuma",
        "klapprig",
        "durchlöchert",
        "Spott",
        "lächerlich",
        "weit verbreitet",
        "Gewehr",
        "Riss",
        "starr",
        "Steifigkeit",
        "Strenge",
        "rigoros",
        "Wecker",
        "randalieren",
        "aufrührerisch",
        "Risiko",
        "riskant",
        "Rivalität",
        "rauben",
        "Räuber",
        "Raub",
        "Schurke",
        "Turm",
        "verrotten",
        "verrottet",
        "Rauheit",
        "NO TRANSLATION",
        "Reihe",
        "Rowdy",
        "Müll",
        "Schutt",
        "bereuen",
        "Rüsche",
        "robust",
        "Ruine",
        "ruiniert",
        "ruinös",
        "Gerücht",
        "Renn weg",
        "Bruch",
        "NO TRANSLATION",
        "Rost",
        "rostig",
        "rücksichtslos",
        "NO TRANSLATION",
        "Sabotage",
        "Opfer",
        "traurig",
        "Traurigkeit",
        "durchhängen",
        "Saft",
        "Sarkasmus",
        "Sarkom",
        "sardisch",
        "satanisch",
        "gesättigt",
        "Wilde",
        "Wildheit",
        "Schorf",
        "Gerüst",
        "Skalpell",
        "schuppig",
        "Skandal",
        "skandalös",
        "spärlich",
        "Sündenbock",
        "Narbe",
        "knapp",
        "kaum",
        "Knappheit",
        "Schrecken",
        "Assgeier",
        "planen",
        "Schisma",
        "Schizophrenie",
        "Ischias",
        "spotten",
        "schelten",
        "Schelte",
        "sengend",
        "Verachtung",
        "Skorpion",
        "Scotch",
        "Schurke",
        "Geißel",
        "kriechend",
        "Scrapie",
        "Schrei",
        "schreiend",
        "kreischen",
        "geschraubt",
        "Scrimmage",
        "schrubben",
        "prüfen",
        "Überprüfung",
        "Abschaum",
        "anbraten",
        "Sezession",
        "abgelegen",
        "NO TRANSLATION",
        "Sekretion",
        "geheimnisvoll",
        "sektiererisch",
        "Aufruhr",
        "verführen",
        "Verführung",
        "trennen",
        "abgesondert",
        "ergreifen",
        "egoistisch",
        "Selbstsucht",
        "senil",
        "sinnlos",
        "Satz",
        "Separatist",
        "Sepsis",
        "septisch",
        "Sequestrierung",
        "heiter",
        "Schlange",
        "Diener",
        "Dienen",
        "servil",
        "Knechtschaft",
        "Rückschlag",
        "trennen",
        "Abwasser",
        "Kanalisation",
        "schäbig",
        "Hütte",
        "Schäkel",
        "schattig",
        "Schütteln",
        "wackelig",
        "Schein",
        "Scherben",
        "Schande",
        "beschämend",
        "schamlos",
        "Shanghai",
        "Hai",
        "zerschmettern",
        "zerschlagen",
        "Schuppen",
        "Schale",
        "aufgeschoben",
        "Schiffswrack",
        "Scheisse",
        "Schauer",
        "Schock",
        "Shoddy",
        "schießen",
        "Schießen",
        "Ladendiebstahl",
        "Mangel",
        "Mangel",
        "Schuss",
        "schieben",
        "auffällig",
        "Schrei",
        "schrillen",
        "schrumpfen",
        "geschrumpft",
        "schaudern",
        "meiden",
        "krank",
        "widerlich",
        "kränklich",
        "Krankheit",
        "dumm",
        "NO TRANSLATION",
        "sündhaft",
        "unheimlich",
        "Sünder",
        "sündigen",
        "Sirene",
        "Weichei",
        "skeptisch",
        "skizzenhaft",
        "verzerrt",
        "Schleudern",
        "überspringen",
        "Scharmützel",
        "locker",
        "Schlacke",
        "zuschlagen",
        "Verleumdung",
        "verleumderisch",
        "schlagen",
        "schlachten",
        "Schlachthof",
        "Schlachten",
        "Sklave",
        "Sklaverei",
        "erschlagen",
        "Jäger",
        "Schneeregen",
        "schleimig",
        "schleichen",
        "Unterhose",
        "NO TRANSLATION",
        "schlampig",
        "Faultier",
        "lümmeln",
        "Sumpf",
        "Langsamkeit",
        "Schlamm",
        "Schnecke",
        "träge",
        "Slum",
        "Einbruch",
        "Bogen",
        "Matsch",
        "Schlampe",
        "schlau",
        "klatschen",
        "klein",
        "Smash",
        "zerschmettert",
        "klappernd",
        "Geruch",
        "riechend",
        "Grinsen",
        "schlagen",
        "Raucher",
        "ersticken",
        "verschmieren",
        "selbstgefällig",
        "schmuggeln",
        "Schmuggler",
        "Schmuggel",
        "Schmutz",
        "Haken",
        "Haken",
        "Schlange",
        "Schlinge",
        "Knurren",
        "knurrend",
        "schleichen",
        "schleichen",
        "spotten",
        "niesen",
        "abfallen",
        "Snob",
        "einweichen",
        "NO TRANSLATION",
        "Sozialist",
        "Boden",
        "verschmutzt",
        "somatisch",
        "düster",
        "Ruß",
        "Zauberei",
        "schmutzig",
        "wund",
        "schmerzlich",
        "Wundheit",
        "Trauer",
        "traurig",
        "NO TRANSLATION",
        "seelenlos",
        "Seelenverwandte",
        "sauer",
        "versohlen",
        "Krampf",
        "Spuck",
        "Speer",
        "Fleck",
        "Gespenst",
        "spektral",
        "Spekulation",
        "verbraucht",
        "Jungfer",
        "Trotz",
        "gehässig",
        "Splitter",
        "Teilt",
        "Aufspaltung",
        "verwöhnen",
        "Spoiler",
        "gesprochen",
        "Schwamm",
        "Spuk",
        "Verstauchung",
        "Spree",
        "Sprite",
        "unecht",
        "Bö",
        "Squatter",
        "zimperlich",
        "Rauschsperre",
        "winden",
        "stechen",
        "Staffelung",
        "stagnierend",
        "Fleck",
        "alt",
        "Stengel",
        "Abstand",
        "still stehen",
        "starrend",
        "Stark",
        "erschrecken",
        "Hunger",
        "verhungert",
        "verhungernd",
        "stationär",
        "Daube",
        "stehlen",
        "stehlen",
        "verstohlen",
        "Stereotyp",
        "stereotyp",
        "steril",
        "Sterilität",
        "Stern",
        "steif",
        "Steifheit",
        "ersticken",
        "erstickt",
        "Stigma",
        "tot geboren",
        "Stachel",
        "stechend",
        "geizig",
        "stinken",
        "stinkend",
        "Stint",
        "Bestände",
        "gestohlen",
        "Stein",
        "entsteint",
        "Hocker",
        "Stillstand",
        "Sturm",
        "stürmisch",
        "angespannt",
        "Meerenge",
        "gestrandet",
        "Fremder",
        "erwürgen",
        "verirrt",
        "Stress",
        "Streit",
        "Streik",
        "Streifen",
        "Streifen",
        "abgestreift",
        "Schlaganfall",
        "Kampf",
        "Strebe",
        "stickig",
        "stolpern",
        "betäubt",
        "verkümmert",
        "blöd",
        "Dummheit",
        "Stupor",
        "Stall",
        "unterwerfen",
        "Gegenstand",
        "unterworfen",
        "Unterwerfung",
        "Unterwerfung",
        "untergeordnet",
        "Vorladung",
        "Senkung",
        "Subvention",
        "bestehen",
        "subtrahieren",
        "Subversion",
        "subversiv",
        "untergraben",
        "erliegen",
        "saugen",
        "Saugnapf",
        "verklagen",
        "leiden",
        "Leidende",
        "Leiden",
        "erstickend",
        "Erstickung",
        "lebensmüde",
        "Selbstmord",
        "mürrisch",
        "Ladung",
        "gesunken",
        "oberflächlich",
        "überflüssig",
        "abergläubisch",
        "unterdrücken",
        "Unterdrückung",
        "Zuschlag",
        "mürrisch",
        "Kapitulation",
        "Übergabe",
        "anfällig",
        "vermuten",
        "Suspension",
        "Verdacht",
        "verdächtig",
        "Tupfer",
        "Sumpf",
        "sumpfig",
        "Hakenkreuz",
        "Schwellung",
        "Schluck",
        "Schwein",
        "geschwollen",
        "Symptom",
        "Synkope",
        "Tabu",
        "verderben",
        "NO TRANSLATION",
        "verheddert",
        "Verspätung",
        "spät",
        "Tarif",
        "trüben",
        "verweilen",
        "geschmacklos",
        "Spott",
        "MwSt",
        "necken",
        "Neckerei",
        "langweilig",
        "NO TRANSLATION",
        "Sturm",
        "Versuchung",
        "Mietshaus",
        "Terminal",
        "Beendigung",
        "Termite",
        "furchtbar",
        "Terror",
        "Terrorismus",
        "Terrorist",
        "terrorisieren",
        "Tetanus",
        "Halteseil",
        "Diebstahl",
        "Theismus",
        "theokratisch",
        "Dieb",
        "durstig",
        "Dorn",
        "dornig",
        "gedankenlos",
        "Thrash",
        "Bedrohung",
        "drohen",
        "bedrohlich",
        "dreschen",
        "pochen",
        "drosseln",
        "Schläger",
        "Schlag",
        "donnernd",
        "vereiteln",
        "Tiff",
        "schüchtern",
        "Schüchternheit",
        "beschwipst",
        "Tirade",
        "müde",
        "Müdigkeit",
        "ermüdend",
        "Meise",
        "Kröte",
        "Tabak",
        "Toilette",
        "Mühsal",
        "tolerieren",
        "Zahnschmerzen",
        "quälen",
        "zerrissen",
        "Torpedo",
        "heiß",
        "delikt",
        "unerfreulich",
        "Folter",
        "berührt",
        "empfindlich",
        "zäh",
        "giftig",
        "Toxin",
        "Tragödie",
        "tragisch",
        "Verräter",
        "Tramp",
        "Trance",
        "Überschreitung",
        "Drumherum",
        "Fallen",
        "Müll",
        "trashig",
        "traumatisch",
        "NO TRANSLATION",
        "Travestie",
        "tückisch",
        "Verrat",
        "Verrat",
        "Zittern",
        "Tremor",
        "Angst",
        "Übertretung",
        "Drangsal",
        "Gericht",
        "Trick",
        "Tricks",
        "Kleinigkeit",
        "Auslösung",
        "Troll",
        "lästig",
        "Trompete",
        "stürzen",
        "Tumor",
        "Tumor",
        "Tumult",
        "stürmisch",
        "Turbulenz",
        "turbulent",
        "Aufruhr",
        "zucken",
        "Taifun",
        "tyrannisch",
        "Tyrannei",
        "Tyrann",
        "Hässlichkeit",
        "hässlich",
        "Geschwür",
        "weiter",
        "Ultimatum",
        "unfähig",
        "inakzeptabel",
        "unberechenbar",
        "nicht genehmigt",
        "ungebunden",
        "unerreichbar",
        "unattraktiv",
        "nicht autorisiert",
        "unvermeidlich",
        "nicht bewusst",
        "unerträglich",
        "Unglaube",
        "nicht zu fassen",
        "ungeboren",
        "unheimlich",
        "nicht entlarvend",
        "unsicher",
        "unveränderlich",
        "unrein",
        "unbequem",
        "unbesonnen",
        "bewusstlos",
        "verfassungswidrig",
        "unkontrollierbar",
        "unkontrolliert",
        "unentschieden",
        "untergraben",
        "unterbezahlt",
        "untermaßig",
        "unerwünscht",
        "unerwünscht",
        "rückgängig machen",
        "Unbehagen",
        "unruhig",
        "ungebildet",
        "arbeitslos",
        "ungleich",
        "uneben",
        "unerklärt",
        "unfair",
        "Ungerechtigkeit",
        "untreu",
        "ungünstig",
        "unvollendet",
        "unversöhnlich",
        "unglücklich",
        "unfreundlich",
        "unerfüllt",
        "unmöbliert",
        "gottlos",
        "undankbar",
        "Unglück",
        "unzufrieden",
        "ungesund",
        "unheilig",
        "unwichtig",
        "unbeeindruckt",
        "unverbessert",
        "nicht informiert",
        "uneingeweihte",
        "uninspiriert",
        "unverständlich",
        "unbeabsichtigt",
        "uninteressiert",
        "uninteressant",
        "ungerecht",
        "nicht zu rechtfertigen",
        "ungerechtfertigt",
        "nicht nett",
        "unbekannte",
        "ungesetzlich",
        "nicht lizenziert",
        "unglücklich",
        "unüberschaubar",
        "unnatürlich",
        "inoffiziell",
        "unbezahlt",
        "unangenehm",
        "unpopulär",
        "unberechenbar",
        "unvorbereitet",
        "unproduktiv",
        "unrentabel",
        "ungeschützt",
        "unveröffentlicht",
        "unzuverlässig",
        "unerwidert",
        "widerspenstig",
        "unsicher",
        "ungenügend",
        "nicht zufrieden",
        "unsäglich",
        "skrupellos",
        "verunsichert",
        "unansehnlich",
        "nicht fortschrittlich",
        "unsagbar",
        "instabil",
        "erfolglos",
        "ungeeignet",
        "unbesungen",
        "nicht unterstützt",
        "nicht nachhaltig",
        "unsympathisch",
        "ungezähmt",
        "unhaltbar",
        "undenkbar",
        "unordentlich",
        "unzeitgemäß",
        "ohne Titel",
        "nicht verkauft",
        "untauglich",
        "untrainiert",
        "unwahr",
        "unseriös",
        "ungerechtfertigt",
        "ungewaschen",
        "unwillkommen",
        "nicht wohl",
        "Unwilligkeit",
        "unklug",
        "unwissend",
        "unwürdig",
        "unnachgiebig",
        "Umbruch",
        "Aufstand",
        "Aufruhr",
        "verärgert",
        "Bengel",
        "dringend",
        "nutzlos",
        "usurpieren",
        "usurpiert",
        "Wucher",
        "Vakanz",
        "leer",
        "vage",
        "Vagheit",
        "vergeblich",
        "Vampir",
        "verschwunden",
        "Eitelkeit",
        "Windpocken",
        "Krampfadern-",
        "vegetativ",
        "vehement",
        "Vendetta",
        "Rache",
        "rachsüchtig",
        "Gift",
        "giftig",
        "Ausführlichkeit",
        "Rand",
        "Ungeziefer",
        "gegen",
        "Schwindel",
        "Einspruch",
        "Laster",
        "bösartig",
        "Opfer",
        "schikaniert",
        "Schurke",
        "schurkisch",
        "rachsüchtig",
        "Verstoß",
        "Gewalt",
        "heftig",
        "heftig",
        "Viper",
        "Virulenz",
        "Virus",
        "Heimsuchung",
        "Füchsin",
        "Volatilität",
        "Vulkan",
        "Erbrechen",
        "Voodoo",
        "vulgär",
        "Vulgarität",
        "Verletzlichkeit",
        "Geier",
        "Waffel",
        "jammern",
        "warten",
        "Suhle",
        "NO TRANSLATION",
        "schwinden",
        "wollend",
        "Krieg",
        "Aufseher",
        "Ware",
        "Krieg",
        "kriegerisch",
        "warnen",
        "Kette",
        "verzogen",
        "Warze",
        "Abfall",
        "verschwendet",
        "verschwenderisch",
        "Verschwendung",
        "wässrig",
        "wanken",
        "geschwächt",
        "schwach",
        "die Schwäche",
        "tragen",
        "müde",
        "Müdigkeit",
        "müde",
        "Unkraut",
        "weinen",
        "seltsam",
        "Verrückter",
        "NO TRANSLATION",
        "Weibsbild",
        "Schlag",
        "Laune",
        "jammern",
        "Peitsche",
        "Wirbelwind",
        "Whiskey",
        "Hure",
        "böse",
        "Bosheit",
        "wild",
        "wilde Katze",
        "ein Lauffeuer",
        "mutwillig",
        "wimpern",
        "feige",
        "zusammenzucken",
        "Hexe",
        "Hexerei",
        "abheben",
        "verdorren",
        "verwelkt",
        "Weh",
        "jämmerlich",
        "erbärmlich",
        "Wörter",
        "Wurm",
        "getragen",
        "besorgt",
        "Sorge",
        "beunruhigend",
        "schlechter",
        "Verschlechterung",
        "wertlos",
        "Wunde",
        "Gerangel",
        "Zorn",
        "anrichten",
        "Wrack",
        "zerstört",
        "Schlüssel",
        "Ringen",
        "Elender",
        "erbärmlich",
        "falsch",
        "Fehlverhalten",
        "falsch",
        "zu Unrecht",
        "geschmiedet",
        "trocken",
        "Fremdenfeindlichkeit",
        "gähnen",
        "Gähnen",
        "Schrei",
        "Gelb",
        "jaulen",
        "Postleitzahl",
    ]
)

_ambivalent = set(
    [
        "Fülle",
        "bewaffnet",
        "Balsam",
        "Prahlerei",
        "ungestüm",
        "Bücherwurm",
        "Bock",
        "Berühmtheit",
        "Fasziniert",
        "Umgehung",
        "Mittäterschaft",
        "bekennen",
        "gerissen",
        "abhängig",
        "vielfältig",
        "dominieren",
        "endlos",
        "erzwingen",
        "erotisch",
        "Flucht",
        "Gefühl",
        "Flirt",
        "Hagel",
        "Hedonismus",
        "höchste",
        "demütigen",
        "sofort",
        "unbeweglich",
        "Einkommen",
        "Infiltration",
        "beeinflussen",
        "heftig",
        "endlos",
        "Intervention",
        "Spitze",
        "Liberale",
        "Herr",
        "mütterlich",
        "Hebamme",
        "Mutter",
        "Becher",
        "Bekanntheit",
        "Allmacht",
        "Ausbruch",
        "hervorragend",
        "Parade",
        "Paraphrase",
        "Petroleum",
        "Vorführung",
        "verschwenderisch",
        "Zitat",
        "Rave",
        "regressiv",
        "wieder aufleben",
        "Überreste",
        "Pensionierung",
        "beleben",
        "Revolution",
        "Vogelscheuche",
        "Abgeschiedenheit",
        "sinnlich",
        "Schauspiel",
        "Rücken",
        "Sterling",
        "saftig",
        "Aberglaube",
        "Vorherrschaft",
        "umgeben",
        "gleichbedeutend",
        "verlockend",
        "Jugendliche",
        "behandeln",
        "ungeschlagen",
        "ungezügelt",
        "unerwartet",
        "unvorstellbar",
        "lösen",
        "bergauf",
        "Abstimmung",
        "Gewicht",
        "Sehnsucht",
    ]
)



"""
Created on Sat Aug 21 18:00:50 2021

@author: alfonso
"""

import networkx as nx
import itertools
from emoatlas.textloader import _clean_text
from emoatlas.language_dependencies import (
    _pronouns,
    _language_code3,
    _valences,
)
import re
import matplotlib.pyplot as plt
from nltk.corpus import wordnet as wn
from collections import namedtuple


def _wordnet_synonyms(vertexlist, language, with_type=False):
    """
    1. For each word `i` in vertexlist, get all synonims `S_i`
    2. For each pair of word in vertexlist that are synonims, draw an edge
       like (i, j \in S_i)
    """
    lang = _language_code3(language)
    if not lang:
        return []

    #    L = len(edgelist)
    synonims_list = [
        list(
            set(
                itertools.chain(
                    *[w.lemma_names(lang) for w in wn.synsets(x, lang=lang)]
                )
            )
        )
        for x in vertexlist
    ]
    synonims_pairs = [
        list(itertools.combinations(syn, 2)) for syn in synonims_list if len(syn) > 0
    ]

    synonims_pairs = [
        [(a, b) for (a, b) in w if a in vertexlist and b in vertexlist]
        for w in synonims_pairs
    ]
    synonims_pairs = list(set(itertools.chain(*synonims_pairs)))

    if with_type:
        synonims_pairs = [(a, b, "synonyms") for a, b in synonims_pairs]

    synonims_pairs

    return synonims_pairs


def _wordnet_hypernyms(vertexlist, language, with_type=False):
    """
    1. For each word `i` in vertexlist, get all hypernyms `S_i`
    2. For each pair of word in vertexlist that are hypernyms and synonyms, draw an edge
       like (i, j \in S_i)
    """
    lang = _language_code3(language)
    if not lang:
        return []

    hypernyms_pairs = []

    for vertex in vertexlist:
        hyp_list = [
            a
            for a in itertools.chain(
                *[
                    [hyp.lemma_names(lang) for hyp in ss.hypernyms()]
                    for ss in wn.synsets(vertex, lang=lang)
                ]
            )
        ]
        hyp_pairs = list(set([(vertex, hyp) for hyp in itertools.chain(*hyp_list)]))
        hyp_pairs = [
            (a, b)
            for a, b in hyp_pairs
            if a != b and a in vertexlist and b in vertexlist
        ]

        hypernyms_pairs.extend(hyp_pairs)

    if with_type:
        hypernyms_pairs = [(a, b, "hypernyms") for a, b in hypernyms_pairs]

    return hypernyms_pairs


# remove duplicates
def f7(seq):
    seen = set()
    seen_add = seen.add
    return [x for x in seq if not (x in seen or seen_add(x))]


# Finds tokens to be negated
def handle_negations(tokens):
    negations = [token for token in tokens if token.dep_ == "neg"]

    tonegate = []

    for neg in negations:
        head = neg.head
        children = [x for x in head.children if "comp" in x.dep_]
        tonegate += [child.lemma_ for child in children]

        for child in children:
            grandchildren = [gc for gc in child.children]
            if not any([gc.text == "but" for gc in grandchildren]):
                grandchildren = [gc.lemma_ for gc in grandchildren if gc.dep_ == "conj"]
                tonegate += grandchildren

    negations = [neg.lemma_ for neg in negations]

    return negations, tonegate


# Replace negated words
def replace_antonyms(lemma, negate_lemmas, antonyms):

    if lemma in negate_lemmas:
        idx, lm = lemma.split("__")
        if lm in antonyms:
            lemma = idx + "__" + antonyms[lm]
        else:
            lemma = idx + "__" + "not-" + lm

    return lemma


def _get_edges_vertex(
    text,
    spacy_model,
    stemmer=None,
    stem_or_lem="lemmatization",
    language="english",
    keepwords=[],
    stopwords=[],
    antonyms={},
    wn=None,
    max_distance=3,
    semantic_enrichment="",
    with_type=False,
):
    """Get an edgelist, with also stopwords in it, and a vertex list with no stopwords in it."""

    if stem_or_lem == "stemming" and stemmer is None:
        raise Exception(
            "Value Error: Stemming was requested instead of lemmatization, but no stemmer was initialized. Please run set_stemming_lemmatization('stemming') before trying again."
        )

    edgelist = []
    vertexlist = []

    #     keeptags = ['JJ', 'JJR', 'JJS', 'CD', 'PRP', 'NN', 'NNS', 'FW', 'NNP', 'NNPS', 'PDT', 'RB', 'RBR',
    #                 'RBS', 'RP', 'VB', 'VBZ', 'VBP', 'VBD', 'VBN', 'VBG'] # this goes with .tag_
    keeppos = [
        "VERB",
        "AUX",
        "NOUN",
        "PROPN",
        "ADJ",
        "NUM",
        "PRON",
        "ADV",
    ]  # this goes with .pos_

    # Getting or using spacy model
    nlp = spacy_model

    # get sentences
    nlp.create_pipe("sentencizer")
    sentences = nlp(text).sents

    for sentence in sentences:

        sent_edges = []
        sent_vertex = []

        # tokenize sentence
        tokens = [token for token in nlp(sentence.text)]
        for i, token in enumerate(tokens):
            token.lemma_ = "{}__".format(i) + token.lemma_

        # some tokens must be negated!
        negations_lemmas, negate_lemmas = handle_negations(tokens)

        for token in tokens:

            # is it a negation? skip it
            if token.lemma_ in negations_lemmas:
                continue

            # a pair <word, parent_word> unless word is ROOT
            if token.dep_ != "ROOT":
                sent_edges += [(token.head.lemma_, token.lemma_)]

            # should you keep the word? Yes if it is in keeppos or it is a negation or a pronoun
            keep = token.pos_ in keeppos
            # reasons to overtake on keep
            nokeep = (
                (token.text in stopwords)
                or (token.is_stop)
                or len(token.text) <= 2
                or bool(re.search("[0-9]", token.text))
            )
            # reasons to overtake on everything
            yakeep = (token.text in keepwords) or (token.text in _pronouns[language])
            # old implementation
            # yakeep = (token.text in keepwords) or (token.text in _negations[language]) or (token.text in _pronouns[language])

            if (keep and not nokeep) or yakeep:
                sent_vertex += [token.lemma_]

        # all the lemmas we kept from the sentence
        sent_vertex = list(
            set(sent_vertex)
        )  # there are NO stopwords in the vertex list.

        # all possible pairs of edges between syntactically dependent words - no matter if we kept them!
        sent_edges = f7(sent_edges)  # there are stopwords in the edgelist!

        # only edges between words at distance < threshold
        sent_edges, sent_vertex = _get_network(sent_edges, sent_vertex, max_distance)

        # Replace antonyms
        if negate_lemmas:
            sent_vertex = [
                replace_antonyms(word, negate_lemmas, antonyms) for word in sent_vertex
            ]
            sent_edges = [
                (
                    replace_antonyms(a, negate_lemmas, antonyms),
                    replace_antonyms(b, negate_lemmas, antonyms),
                )
                for a, b in sent_edges
            ]

        # stemming?
        if stem_or_lem == "stemming":
            sent_vertex = [stemmer.stem(word) for word in sent_vertex]
            sent_edges = [(stemmer.stem(a), stemmer.stem(b)) for a, b in sent_edges]

        # with type?
        if with_type:
            sent_edges = [(a, b, "syntactic") for a, b in sent_edges]

        # add this sentence's words and edges to global
        edgelist += sent_edges
        vertexlist += sent_vertex

    # remove indexes and add type
    if with_type:
        edgelist = [(a.split("__")[1], b.split("__")[1], c) for a, b, c in edgelist]
    else:
        edgelist = [(a.split("__")[1], b.split("__")[1]) for a, b in edgelist]

    # remove indexes
    vertexlist = list(set([vertex.split("__")[1] for vertex in vertexlist]))

    # add synonims
    if semantic_enrichment == "synonyms" or "synonyms" in semantic_enrichment:
        syn_edges = _wordnet_synonyms(vertexlist, language, with_type)
        edgelist.extend(syn_edges)

    # add hypernyms
    if semantic_enrichment == "hypernyms" or "hypernyms" in semantic_enrichment:
        hyp_edges = _wordnet_hypernyms(vertexlist, language, with_type)
        edgelist.extend(hyp_edges)

    # unique edges and no self-loops
    if with_type:
        edgelist.extend([(b, a, c) for a, b, c in edgelist])
        edgelist = [(a, b, c) for a, b, c in edgelist if a < b]
    else:
        edgelist.extend([(b, a) for a, b in edgelist])
        edgelist = [(a, b) for a, b in edgelist if a < b]

    edgelist = f7(edgelist)

    return edgelist, vertexlist


def _get_network(edges, vertex, max_distance=3):
    """Builds a graph from the edgelist, keeps only pairs of vertex that:
    - are at maximum distance of `max_distance` links
    - are both in the vertex list
    """

    G = nx.Graph(edges)

    #     spl = nx.all_pairs_shortest_path_length(G, cutoff = max_distance)
    #     print(dict(spl))
    spl = nx.all_pairs_shortest_path_length(G, cutoff=max_distance)

    # spl is {source: {target: distance}, ... }
    # must check that:
    # 1. source != target
    # 2. source in vertex, target in vertex
    # 3. distance <= max_distance
    edges = [
        [
            (source, target)
            for target, distance in path.items()
            if (1 <= distance <= max_distance) and (target in vertex)
        ]
        for source, path in dict(spl).items()
        if source in vertex
    ]

    # unlist
    edges = list(itertools.chain(*edges))

    # list of lists of tuples (a, b), where a < b, no duplicates
    edges = [(a, b) for a, b in edges if a < b]

    return edges, vertex


def get_formamentis_edgelist(
    text,
    language="english",
    spacy_model="en_core_web_sm",
    stemmer=None,
    stem_or_lem="lemmatization",
    target_word=None,
    keepwords=[],
    stopwords=[],
    antonyms=None,
    max_distance=3,
    semantic_enrichment="synonyms",
    multiplex=False,
    idiomatic_tokens=None,
):
    """
    FormaMentis edgelist from input text.

    Required arguments:
    ----------

    *text*:
        A string, the text to extract emotions from.

    *language*:
        Language of the text. Full support is offered for the languages supported by Spacy:
            Catalan, Chinese, Danish, Dutch, English, French, German, Greek, Japanese, Italian, Lithuanian,
            Macedonian, Norvegian, Polish, Portuguese, Romanian, Russian, Spanish.
        Limited support for other languages is available.

    *target_word*:
        A string or None. If a string and method is 'formamentis', it will be computed the emotion distribution
        only of the neighborhood of 'target_word' in the formamentis network.

    *keepwords*:
        A list. Words that shall be included in formamentis networks regardless from their part of speech. Default is an empty list.
        By default implementation, a pre-compiled list of negations and pronouns will be loaded and used as keepwords.

    *stopwords*:
        A list. Words that shall be discarded from formamentis networks regardless from their part of speech. Default is an empty list.
        If a word is both in stopwords and in keepwords, the word will be discarded.

    *max_distance*:
        An integer, by default 2. Links in the formamentis network will be established from each word to each neighbor within a distance
        defined by max_distance.

     *semantic_enrichment*:
        A str or a list of str. If 'synonyms', will be added semantic arcs between synonyms into the network. If 'hypernyms', will be
        added semantic arcs between hypernyms and hyponyms. Also ['synonyms', 'hypernyms'] is accepted.

    *multiplex*:
        A bool: whether to return different edgelist for different kinds of edges (syntactic, synonyms, hypernyms) or not. Default is False.


    Returns:
    ----------
    *edges*:
        A list of 2-items tuples, defining the edgelist of the formamentis network. If multiplex is True,
        it returns a dictionary with syntactic and semantic edges separately.

    *vertex*:
        A list of string, defining the list of vertices of the network.

    """

    # semantic_enrichment must be either a string in ['synonyms', 'hypernyms']
    accepted_values = ["synonyms", "hypernyms", ""]

    if type(semantic_enrichment) == str and semantic_enrichment not in accepted_values:
        wrong = [val for val in semantic_enrichment if val not in accepted_values][0]
        raise Exception(
            f"Value Error: wrong value '{wrong}' for semantic enrichment: it must be either 'synonyms', 'hypernyms' or empty, or any combination of the above."
        )
    elif semantic_enrichment is None:
        semantic_enrichment = ""
    elif type(semantic_enrichment) == list and any(
        [val not in accepted_values for val in semantic_enrichment]
    ):
        wrong = [val for val in semantic_enrichment if val not in accepted_values][0]
        raise Exception(
            f"Value Error: wrong value '{wrong}' for semantic enrichment: it must be either 'synonyms', 'hypernyms' or empty, or any combination of the above."
        )

    text = _clean_text(text)

    with_type = multiplex

    edges, vertex = _get_edges_vertex(
        text=text,
        spacy_model=spacy_model,
        stemmer=stemmer,
        stem_or_lem=stem_or_lem,
        language=language,
        keepwords=keepwords,
        stopwords=stopwords,
        antonyms=antonyms,
        max_distance=max_distance,
        semantic_enrichment=semantic_enrichment,
        with_type=with_type,
    )

    # target words!
    if target_word:
        neighbors = list(
            set(list(itertools.chain(*[e for e in edges if target_word in e])))
        )

        if with_type:
            edges = [
                (a, b, c) for a, b, c in edges if a in neighbors and b in neighbors
            ]
            vertex = list(
                set.union(set([a for a, _, _ in edges]), set([b for _, b, _ in edges]))
            )
        else:
            edges = [(a, b) for a, b in edges if a in neighbors and b in neighbors]
            vertex = list(
                set.union(set([a for a, _ in edges]), set([b for _, b in edges]))
            )

    # should we return a dictionary?
    if multiplex:
        edgelist = {}
        edgelist["syntactic"] = [(a, b) for a, b, c in edges if c == "syntactic"]
        if "synonyms" == semantic_enrichment or "synonyms" in semantic_enrichment:
            edgelist["synonyms"] = [(a, b) for a, b, c in edges if c == "synonyms"]
        if "hypernyms" == semantic_enrichment or "hypernyms" in semantic_enrichment:
            edgelist["hypernyms"] = [(a, b) for a, b, c in edges if c == "hypernyms"]
        edges = edgelist

    FormamentisNetwork = namedtuple("FormamentisNetwork", "edges vertices")
    return FormamentisNetwork(edges, vertex)


def draw_formamentis(edgelist, language="english", ax=None):
    """ """

    # Get the network
    M = nx.MultiGraph()
    M.add_edges_from(edgelist)

    try:
        _ = edgelist[0][2]
        color = ["blue" if t[2] == "syntactic" else "red" for t in edgelist]
    except:
        color = ["grey" for _ in range(len(edgelist))]

    # Get positive or negative valences
    _positive, _negative, _ambivalent = _valences(language)

    # Prepare the patch effect for bicolor patches
    import matplotlib.patheffects as path_effects

    eff = [
        path_effects.PathPatchEffect(facecolor="white", edgecolor="red", linewidth=2),
        path_effects.PathPatchEffect(
            edgecolor="green", linewidth=2.1, facecolor=(0, 0, 0, 0), linestyle="--"
        ),
    ]

    if not ax:
        _, ax = plt.subplots(figsize=(9, 9))

    pos = nx.spring_layout(M)
    nx.draw_networkx(
        M,
        pos=pos,
        node_size=0,
        with_labels=False,
        font_size=12,
        edge_color=color,
        width=3.5,
        alpha=0.5,
    )
    for key, val in pos.items():

        if key in _positive:
            plt.annotate(
                s=key,
                xy=(val[0], val[1]),
                bbox=dict(boxstyle="round", fc="white", ec="green", linewidth=4),
            )

        if key in _negative:
            plt.annotate(
                s=key,
                xy=(val[0], val[1]),
                bbox=dict(boxstyle="round", fc="white", ec="red", linewidth=4),
            )

        if key in _ambivalent:
            plt.annotate(
                s=key,
                xy=(val[0], val[1]),
                bbox=dict(
                    boxstyle="round",
                    fc="white",
                    ec=(119 / 255, 221 / 255, 118 / 255, 0.7),
                    path_effects=eff,
                    linewidth=1,
                ),
            )
        else:
            plt.annotate(
                s=key,
                xy=(val[0], val[1]),
                bbox=dict(boxstyle="round", fc="white", ec="grey", linewidth=1),
            )
    ax.axis("off")



import matplotlib.patches as mpatches
import matplotlib.path as mpath
from matplotlib.collections import PatchCollection
import networkx as nx
from deep_translator import GoogleTranslator

import community.community_louvain as commlouv
from emoatlas.resources import _valences
import matplotlib.pyplot as plt
from math import cos, sin, radians
from decimal import Decimal as D

language_codes = {
    "catalan": "ca",
    "chinese": "zh",
    "danish": "da",
    "dutch": "nl",
    "english": "en",
    "french": "fr",
    "german": "de",
    "greek": "el",
    "italian": "it",
    "japanese": "ja",
    "lithuanian": "lt",
    "macedonian": "mk",
    "norwegian": "no",
    "polish": "pl",
    "portoguese": "pt",
    "romanian": "ro",
    "russian": "ru",
    "spanish": "es",
}


def _rotate_point(point, angle):
    """
    Rotate a point counterclockwise by a given angle around a given origin.
    Required arguments:
    ----------
    *point*:
        A two-values tuple, (x, y), of the point to rotate

    *angle*:
        The angle the point is rotated. The angle should be given in radians.

    Returns:
    ----------
    *(qx, qy)*:
        A two-values tuple, the new coordinates of the rotated point.

    """
    ox, oy = 0, 0
    px, py = point
    angle = radians(angle)
    qx = ox + cos(angle) * (px - ox) - sin(angle) * (py - oy)
    qy = oy + sin(angle) * (px - ox) + cos(angle) * (py - oy)
    return (qx, qy)


def _label_rot_params(i, N, d):
    if 0 < i < N / 4:
        rotation = 270 + round(d * i) % 90
        align1 = "right"
        align2 = "bottom"
    elif i < N / 2:
        rotation = round(d * i) % 90
        align1 = "right"
        align2 = "top"
    elif i <= N * 0.75:
        rotation = 270 + round(d * i) % 90
        # fixing bug horizontal
        if (round(d * i) % 90) <= 0.0000001:
            rotation = round(d * i)
            rotation += 90
        align1 = "left"
        align2 = "top"
    else:
        rotation = round(d * i) % 90
        align1 = "left"
        align2 = "bottom"

    align2 = "center"
    return rotation, align1, align2


def _draw_edge(s, t, pos, louv):

    if louv[s] == louv[t]:
        mx = (pos[s][0] + pos[t][0] / 2) * 0.2
        my = (pos[s][1] + pos[t][1] / 2) * 0.2
        alpha = 0.3
    else:
        mx, my = (0, 0)
        alpha = 0.5

    # Define Bezier curve
    Path = mpath.Path
    path_data = [(Path.MOVETO, pos[s]), (Path.CURVE3, (mx, my)), (Path.CURVE3, pos[t])]

    # add the Path to ax
    codes, verts = zip(*path_data)
    path = mpath.Path(verts, codes)
    patch = mpatches.PathPatch(path)

    return alpha, patch


def _edge_params(w1, w2, _positive, _negative, _ambivalent, base_linewidth, colz):

    if w1 in _positive and w2 in _positive:
        return colz["positive"], 3 * base_linewidth, 1
    if w1 in _negative and w2 in _negative:
        return colz["negative"], 3 * base_linewidth, 1

    if w1 in _negative and w2 in _positive:
        return "purple", 3 * base_linewidth, 1
    if w1 in _positive and w2 in _negative:
        return "purple", 3 * base_linewidth, 1

    if w1 in _positive or w2 in _positive:
        return colz["semipositive"], 2 * base_linewidth, -1
    if w1 in _negative or w2 in _negative:
        return colz["seminegative"], 2 * base_linewidth, -1

    return "lightgrey", base_linewidth, -1


def _hex_to_rgb(value):
    value = value.lstrip("#")
    lv = len(value)
    lv = [int(value[i : i + lv // 3], 16) for i in range(0, lv, lv // 3)]
    lv = [l / 255 for l in lv] + [1]
    return lv


def draw_formamentis_circle_layout(
    fmn,
    highlight=[],
    language="english",
    thickness=15,
    ax=None,
    translated=False,
    alpha_syntactic=0.5,
    alpha_hypernyms=0.5,
    alpha_synonyms=0.5,
):
    """ """

    # Define color-blind palette
    colz = {
        "positive": (26 / 256, 133 / 256, 255 / 256),
        "negative": (255 / 256, 25 / 256, 25 / 256),  # (212/256, 17/256, 89/256),
        "synonyms": (0 / 256, 158 / 256, 115 / 256),
        "hypernyms": (230 / 256, 159 / 256, 0 / 256),
        "semipositive": (117 / 256, 152 / 256, 191 / 256),
        "seminegative": (200 / 256, 50 / 256, 50 / 256),
    }  # (196/256, 128/256, 153/256)}

    # Get positive or negative valences
    _positive, _negative, _ambivalent = _valences(language)

    if not ax:
        _, ax = plt.subplots(figsize=(16, 16))

    # Getting edgelist stripped of type
    if type(fmn.edges) == list:
        edge_type = ["syntactic"] * len(fmn.edges)
        edgelist = fmn.edges
    else:
        edgelist = []
        edge_type = []

        edgelist.extend(fmn.edges["syntactic"])
        edge_type.extend(["syntactic"] * len(fmn.edges["syntactic"]))

        try:
            edgelist.extend(fmn.edges["synonyms"])
            edge_type.extend(["synonyms"] * len(fmn.edges["synonyms"]))
        except:
            pass

        try:
            edgelist.extend(fmn.edges["hypernyms"])
            edge_type.extend(["hypernyms"] * len(fmn.edges["hypernyms"]))
        except:
            pass

    ## Graph and clusters
    G = nx.Graph(edgelist)
    louv = commlouv.best_partition(G)
    louv2 = {
        comm: [key for key, val in louv.items() if val == comm]
        for comm in set(louv.values())
    }

    # Compute nodes sizes after their degree
    degrees = dict(G.degree())
    mindeg, maxdeg = min(degrees.values()), max(degrees.values())
    if mindeg == maxdeg:
        maxdeg = mindeg + 1
    degrees = {
        key: 15 * (val - mindeg) / (maxdeg - mindeg) for key, val in degrees.items()
    }

    ## Draw nodes

    N = len(fmn.vertices) + len(
        louv2
    )  # N nodes require N endpoints + one space per cluster
    d = 360 / N

    pos = {}
    i = 0
    comm = 0
    counter = 0

    for _ in range(len(louv)):

        # get position and space clusters
        if len(louv2[comm]) == 0:
            comm += 1
            i += 1

        v = louv2[comm].pop()
        i += 1
        counter += 1

        # compute position and rotation of label
        x, y = _rotate_point((0, 1), D(d) * D(i))
        pos[v] = (x, y)
        rotation, align1, align2 = _label_rot_params(i, N, d)

        # customization of label
        fz = 16 / (N ** (3 / 5)) * 10 + degrees[v]

        if v in _positive:
            color = colz["positive"]
        elif v in _negative:
            color = colz["negative"]
        else:
            color = "#030303"

        if translated == False:
            if v in highlight:
                ax.text(
                    x,
                    y,
                    " {} ".format(v),
                    rotation=rotation,
                    weight="bold",
                    bbox=dict(facecolor="none", edgecolor=color, linewidth=3),
                    rotation_mode="anchor",
                    ha=align1,
                    va=align2,
                    fontsize=fz,
                    color=color,
                )
            else:
                ax.text(
                    x,
                    y,
                    " {} ".format(v),
                    rotation=rotation,
                    rotation_mode="anchor",
                    ha=align1,
                    va=align2,
                    fontsize=fz,
                    color=color,
                )

        elif translated == True:

            if v in highlight:
                ax.text(
                    x,
                    y,
                    " {} ".format(
                        GoogleTranslator(source=language_codes[language], target="en")
                        .translate(v)
                        .lower()
                    ),
                    rotation=rotation,
                    weight="bold",
                    bbox=dict(facecolor="none", edgecolor=color, linewidth=3),
                    rotation_mode="anchor",
                    ha=align1,
                    va=align2,
                    fontsize=fz,
                    color=color,
                )
            else:
                ax.text(
                    x,
                    y,
                    " {} ".format(
                        GoogleTranslator(source=language_codes[language], target="en")
                        .translate(v)
                        .lower()
                    ),
                    rotation=rotation,
                    rotation_mode="anchor",
                    ha=align1,
                    va=align2,
                    fontsize=fz,
                    color=color,
                )

    ## DRAW ARCHS
    patches = []
    alphas = []
    colors = []
    lws = []
    zors = []

    j = 0
    for s, t in edgelist:
        alpha, patch = _draw_edge(s, t, pos, louv)

        color, linewidth, zorder = _edge_params(
            s, t, _positive, _negative, _ambivalent, thickness, colz
        )

        # Patch: if the edge is semantic we should color it as semantic
        if edge_type[j] == "synonyms":
            color = colz["synonyms"]
            alpha = alpha * (2 * alpha_synonyms)
        elif edge_type[j] == "hypernyms":
            color = colz["hypernyms"]
            alpha = alpha * (2 * alpha_hypernyms)
        else:
            alpha = alpha * (2 * alpha_syntactic)

        alphas.append(alpha)
        patches.append(patch)

        colors.append(color)
        lws.append(linewidth)
        zors.append(zorder)

        j += 1

    patches = PatchCollection(
        patches,
        facecolor="none",
        linewidth=lws,
        edgecolor=colors,
        match_original=True,
        alpha=alphas,
        zorder=1,
        linewidths=lws,
    )
    ax.add_collection(patches)

    plt.xlim((-1.5, 1.5))
    plt.ylim((-1.5, 1.5))

    ax.axis("off")
    return ax
